@@ -1,8 +1,8 @@
 /* GKrellM
-|  Copyright (C) 1999-2019 Bill Wilson
+|  Copyright (C) 1999-2021 Bill Wilson
 |
-|  Author:  Bill Wilson    billw@gkrellm.net
-|  Latest versions might be found at:  http://gkrellm.net
+|  Author:  Bill Wilson
+|  Latest versions might be found at:  https://gkrellm.srcbox.net
 |
 |
 |  GKrellM is free software: you can redistribute it and/or modify it
@@ -42,12 +42,13 @@
 #define MBOX_MH_DIR		2
 
 
-typedef struct
+typedef struct Mailbox Mailbox;
+struct Mailbox
 	{
 	gchar		*path;
 	gchar		*homedir_path;
 	gint		mboxtype;
-	gboolean	(*check_func)();
+	gboolean	(*check_func)(Mailbox *mbox);
 	gint		mail_count;
 	gint		new_mail_count;
 	gint		old_mail_count;
@@ -57,8 +58,7 @@ typedef struct
 	off_t		last_size;
 	gboolean	is_internal;	/* Internal mail message (ie: localmachine) */
 	gboolean	changed;
-	}
-	Mailbox;
+	};
 
 static GList	*mailbox_list;
 
@@ -110,7 +110,7 @@ is_multipart_mail(gchar *buf, gchar *separator)
 	gchar *fieldstart;
 	gchar *sepstart;
 	gint  seplen;
-	
+
 	if (strncmp(buf, "Content-Type: ", 14) != 0)
 		return FALSE;
 	if (strncmp(&buf[14], "multipart/", 10) != 0)
@@ -328,12 +328,12 @@ check_maildir(Mailbox *mbox)
   |  And Netscape mail does status with X-Mozilla-Status: xxxS
   |    where S is bitwise or of status flags:
   |    1: read  2: replied  4: marked  8: deleted
-  |  
+  |
   |  Evolution uses status with X-Evolution: 00000000-xxxx where xxxx status is
   |  a bitfield in hexadecimal (see enum _CamelMessageFlags in evolution/camel
   |  source) and most importantly CAMEL_MESSAGE_SEEN = 1<<4.
   */
-  /* test if buf is a status for standard mail, mozilla or evolution 
+  /* test if buf is a status for standard mail, mozilla or evolution
   */
 static gboolean
 is_status(gchar *buf)
@@ -386,7 +386,7 @@ status_is_old(gchar *buf)
 	return FALSE;
 	}
 
-  /* test if a mail is marked as deleted  
+  /* test if a mail is marked as deleted
   |  Evolution uses status with X-Evolution: 00000000-xxxx where xxxx status is
   |  a bitfield in hexadecimal (see enum _CamelMessageFlags in evolution/camel source)
   |  and most importantly CAMEL_MESSAGE_DELETED = 1<<1.
@@ -660,7 +660,8 @@ static GkrellmdMonitor mail_monitor =
 	"mail",
 	update_mail,
 	serve_mail_data,
-	serve_mail_setup
+	serve_mail_setup,
+	NULL
 	};
 
 GkrellmdMonitor *
