@@ -1,8 +1,8 @@
 /* GKrellM
-|  Copyright (C) 1999-2019 Bill Wilson
+|  Copyright (C) 1999-2021 Bill Wilson
 |
-|  Author:  Bill Wilson    billw@gkrellm.net
-|  Latest versions might be found at:  http://gkrellm.net
+|  Author:  Bill Wilson
+|  Latest versions might be found at:  https://gkrellm.srcbox.net
 |
 |
 |  GKrellM is free software: you can redistribute it and/or modify it
@@ -47,7 +47,7 @@ typedef enum
 	BATTERYDISPLAY_RATE,
 	BATTERYDISPLAY_EOM	/* end of modes */
 	}
-	BatteryDisplayMode; 
+	BatteryDisplayMode;
 
 
 typedef struct
@@ -96,7 +96,7 @@ static gint				style_id;
 static gboolean			alert_units_percent,
 						alert_units_need_estimate_mode;
 
-static void		(*read_battery_data)();
+static GkrellmBatteryReadFunc read_battery_data;
 static void		create_battery_panel(Battery *bat, gboolean first_create);
 
 static gint		n_batteries;
@@ -178,8 +178,8 @@ setup_battery_interface(void)
 	return read_battery_data ? TRUE : FALSE;
 	}
 
-void 
-gkrellm_battery_client_divert(void (*read_func)())
+void
+gkrellm_battery_client_divert(GkrellmBatteryReadFunc read_func)
 	{
 	read_battery_data = read_func;
 	}
@@ -211,11 +211,11 @@ gkrellm_battery_full_cap_fallback(void)
 /* -------------------------------------------------------------- */
 
 
-/* estimate (guess-timate?) battery time remaining, based on the rate of 
+/* estimate (guess-timate?) battery time remaining, based on the rate of
    discharge (and conversely the time to charge based on the rate of charge).
   - some BIOS' only provide battery levels, not any estimate of the time
     remaining
-    
+
   Battery charge/discharge characteristics (or, why dc/dt doesn't really work)
   - the charge/discharge curves of most battery types tend to be very non-
     linear (http://www.google.com/search?q=battery+charge+discharge+curve)
@@ -233,18 +233,18 @@ gkrellm_battery_full_cap_fallback(void)
     final stages of charging are very gradual, with a relatively long
     period at "almost but not quite 100%".
 
-    Unfortunately a linear extrapolation at the beginning of an 
+    Unfortunately a linear extrapolation at the beginning of an
     exponential curve will be a poor approximation to the true expected
-    time to charge, tending to be significantly undervalued. Using an 
+    time to charge, tending to be significantly undervalued. Using an
     exponential model to estimate time to approx. 90-95% (2.5 * exp. time
     constant) seems to give a more reasonable fit. That said, the poor
     relative resolution at higher charge values makes estimating the
-    exponential time constant difficult towards the end of the charge 
-    cycle (the curve's very nearly flat). So, I've settled on a mixed 
+    exponential time constant difficult towards the end of the charge
+    cycle (the curve's very nearly flat). So, I've settled on a mixed
     model - for c < ~70 I use an exponential model, and switch to linear
     above that (or if the charge rate seems to have otherwise "flatlined").
 
-    Empirically, this method seems to give reasonable results [1] - 
+    Empirically, this method seems to give reasonable results [1] -
     certainly  much better than seeing "0:50:00 to full" for a good half an
     hour (i.e. as happens with apmd, which uses a linear model for both
     charging + discharging). Note that a constant-current charger should
@@ -254,23 +254,23 @@ gkrellm_battery_full_cap_fallback(void)
 
     [1] I logged my Compaq Armada M300's capacity (via /proc/apm) over one
     complete discharge/charge cycle (machine was idle the whole time). The
-    discharge curve was linear to approx. 14% when the BIOS alerted of 
+    discharge curve was linear to approx. 14% when the BIOS alerted of
     impending doom; upon plugging in the external power supply the capacity
-    rose exponentially to 100%, with a time constant of approx. 0.8 hr (i.e. 
+    rose exponentially to 100%, with a time constant of approx. 0.8 hr (i.e.
     approx. 2+ hrs to full charge).
 
   Linear rate of change calculation:
-  - in an ideal, continuous world, estimated time to 0(100) would simply 
+  - in an ideal, continuous world, estimated time to 0(100) would simply
     be the remaining capacity divided by the charge rate
        ttl = c / dc(t)/dt
-  - alas, the reported battery capacity is bound to integer values thus 
+  - alas, the reported battery capacity is bound to integer values thus
     c(t) is a discontinuous function. i.e. has fairly large steps. And of
     course then dc/dt is undefined at the discontinuities.
   - to avoid this issue the rate of charge is determined by the deltas from
     the start of the last state change (charge/discharge cycle) (time T)
        ttl(t) = c(t) / ((C - c(t)) / (T - t))    C = charge at time T
-    Furthermore, the rate changes are windowed and filtered to mitigate 
-    c(t) transients (e.g. at the start of discharge) and smooth over 
+    Furthermore, the rate changes are windowed and filtered to mitigate
+    c(t) transients (e.g. at the start of discharge) and smooth over
     discontinuities (and fudge for battery characteristics, ref. above).
 */
 
@@ -283,7 +283,7 @@ gkrellm_battery_full_cap_fallback(void)
 
 /* #define BAT_ESTIMATE_DEBUG */
 
-  /* user-provided nominal battery runtimes, hrs (used to determine initial 
+  /* user-provided nominal battery runtimes, hrs (used to determine initial
   |  discharge, stable, charge rate (%/min))
   */
 static gfloat	estimate_runtime[2] = {0};
@@ -306,8 +306,8 @@ estimate_battery_time_left(Battery *bat)
 	gint			charging = bat->charging ? 1 : (bat->on_line ? 0 : -1);
 
 #ifdef BAT_ESTIMATE_DEBUG
-		fprintf(stderr, "%ld bc?=%d ac?=%d (%+d) bp=%d\t", t, 
-			bat->charging, bat->on_line, charging, 
+		fprintf(stderr, "%ld bc?=%d ac?=%d (%+d) bp=%d\t", t,
+			bat->charging, bat->on_line, charging,
 			bat->percent);
 #endif
 
@@ -357,7 +357,7 @@ estimate_battery_time_left(Battery *bat)
 				rate = (1 - BAT_RATE_SMOOTHING/4) * rate;
 			else
 				rate = BAT_RATE_SMOOTHING *
-						((gdouble) dp / (gdouble) (dt/60)) + 
+						((gdouble) dp / (gdouble) (dt/60)) +
 						(1 - BAT_RATE_SMOOTHING) * rate;
 
 #ifdef BAT_ESTIMATE_DEBUG
@@ -373,7 +373,7 @@ estimate_battery_time_left(Battery *bat)
 	if (charging && rate != 0.0)	/* (dis)charging */
 		{
 		gfloat	eta;
-		gint 	p = charging > 0 ? 100 - bat->percent : 
+		gint 	p = charging > 0 ? 100 - bat->percent :
 						bat->percent - BAT_EMPTY_CAPACITY;
 
 		if (   charging > 0 && estimate_model[1]
@@ -409,11 +409,12 @@ draw_time_left_decal(Battery *bat, gboolean force)
 	GkrellmDecal	*d;
 	gchar			buf[16];
 	gint			x, w, t;
-	int				battery_display_mode = bat->display_mode;
 	static BatteryDisplayMode	last_mode = BATTERYDISPLAY_EOM;
 
 	if (!bat->panel)
 		return;
+
+	BatteryDisplayMode battery_display_mode = bat->display_mode;
 	if (bat->time_left == -1)
 		battery_display_mode = BATTERYDISPLAY_PERCENT;
 	if (last_mode != battery_display_mode)
@@ -635,13 +636,13 @@ create_battery_panel(Battery *bat, gboolean first_create)
 
 	if (first_create)
 		{
-		g_signal_connect(G_OBJECT(p->drawing_area), "expose_event",
+		g_signal_connect(G_OBJECT(p->drawing_area), "expose-event",
 				G_CALLBACK(cb_expose_event), p);
-		g_signal_connect(G_OBJECT(p->drawing_area), "button_press_event",
+		g_signal_connect(G_OBJECT(p->drawing_area), "button-press-event",
 				G_CALLBACK(cb_panel_press), bat);
-		g_signal_connect(G_OBJECT(p->drawing_area), "enter_notify_event",
+		g_signal_connect(G_OBJECT(p->drawing_area), "enter-notify-event",
                 G_CALLBACK(cb_panel_enter), bat);
-		g_signal_connect(G_OBJECT(p->drawing_area), "leave_notify_event",
+		g_signal_connect(G_OBJECT(p->drawing_area), "leave-notify-event",
                 G_CALLBACK(cb_panel_leave), bat);
 		 }
 
@@ -962,7 +963,7 @@ alert_units_percent_cb(GtkToggleButton *button, gpointer data)
 	GList	*list;
 	Battery	*bat;
 
-	alert_units_percent = button->active;
+	alert_units_percent = gtk_toggle_button_get_active(button);
 
 	if (bat_alert)
 		{
@@ -986,7 +987,7 @@ cb_enable_estimate(GtkToggleButton *button, GtkWidget *box)
 	Battery		*bat;
 	gboolean	enable;
 
-	enable = button->active;
+	enable = gtk_toggle_button_get_active(button);
 	gtk_widget_set_sensitive(box, enable);
 
 	if (enable_estimate != enable)
@@ -1035,11 +1036,11 @@ cb_enable(GtkToggleButton *button, gpointer data)
 	gint	which  = GPOINTER_TO_INT(data);
 
 	if (which == 0)
-		enable_composite = enable_each = button->active;
+		enable_composite = enable_each = gtk_toggle_button_get_active(button);
 	else if (which == 1)
-		enable_each = button->active;
+		enable_each = gtk_toggle_button_get_active(button);
 	else if (which == 2)
-		enable_composite = button->active;
+		enable_composite = gtk_toggle_button_get_active(button);
 
 	for (list = battery_list; list; list = list->next)
 		{
@@ -1090,8 +1091,8 @@ cb_estimate_model(GtkWidget *entry, gpointer data)
 	{
 	gint	i = GPOINTER_TO_INT(data);
 
-	estimate_model[i] = 
-			GTK_TOGGLE_BUTTON(estimate_model_button[i])->active;
+	estimate_model[i] =
+			gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(estimate_model_button[i]));
 	reset_estimate = TRUE;
 	update_battery_panels();
 	}
@@ -1102,7 +1103,7 @@ cb_poll_interval(GtkWidget *entry, GtkSpinButton *spin)
 	poll_interval = gtk_spin_button_get_value_as_int(spin);
 	}
 
-static void 
+static void
 cb_launch_entry(GtkWidget *widget, gpointer data)
 	{
 	if (!launch_battery)
@@ -1154,7 +1155,6 @@ create_battery_tab(GtkWidget *tab_vbox)
 	GtkWidget	*tabs, *table, *vbox, *vbox1, *vbox2,
 				*hbox, *hbox2, *text;
 	Battery		*bat;
-	gint		i;
 
 	tabs = gtk_notebook_new();
 	gtk_notebook_set_tab_pos(GTK_NOTEBOOK(tabs), GTK_POS_TOP);
@@ -1187,24 +1187,24 @@ create_battery_tab(GtkWidget *tab_vbox)
 	gtk_box_pack_start(GTK_BOX(vbox), vbox2, FALSE, FALSE, 0);
 
 	vbox1 = gtk_vbox_new(FALSE, 0);
-	gkrellm_gtk_check_button_connected(vbox2, NULL, 
+	gkrellm_gtk_check_button_connected(vbox2, NULL,
 			enable_estimate, FALSE, FALSE, 2,
-			cb_enable_estimate, vbox1, 
+			cb_enable_estimate, vbox1,
 			_("Display estimated time remaining and time to charge"));
 	gtk_widget_set_sensitive(vbox1, enable_estimate ? TRUE : FALSE);
 	gtk_box_pack_start(GTK_BOX(vbox2), vbox1, FALSE, FALSE, 0);
 
 	vbox1 = gkrellm_gtk_category_vbox(vbox1, NULL, 0, 0, TRUE);
-	gkrellm_gtk_spin_button(vbox1, &estimate_runtime_spin_button[0], 
+	gkrellm_gtk_spin_button(vbox1, &estimate_runtime_spin_button[0],
 			estimate_runtime[0], 0.1, 24, 0.1, 1.0, 1, 55,
 			cb_runtime, GINT_TO_POINTER(1), FALSE,
 			_("Total battery run time in hours"));
-	gkrellm_gtk_spin_button(vbox1, &estimate_runtime_spin_button[1], 
+	gkrellm_gtk_spin_button(vbox1, &estimate_runtime_spin_button[1],
 			estimate_runtime[1], 0.1, 24, 0.1, 1.0, 1, 55,
 			cb_runtime, GINT_TO_POINTER(2), FALSE,
 			_("Total battery charge time in hours"));
 
-	gkrellm_gtk_check_button_connected(vbox1, &estimate_model_button[1], 
+	gkrellm_gtk_check_button_connected(vbox1, &estimate_model_button[1],
             estimate_model[1], FALSE, FALSE, 0,
 			cb_estimate_model, GINT_TO_POINTER(1),
 			_("Exponential charge model"));
@@ -1225,7 +1225,7 @@ create_battery_tab(GtkWidget *tab_vbox)
 				_("Launch Commands"),
 				4, 0, TRUE);
 	table = gkrellm_gtk_launcher_table_new(vbox1, 1);
-	gkrellm_gtk_config_launcher(table, 0, &launch_entry, &tooltip_entry, 
+	gkrellm_gtk_config_launcher(table, 0, &launch_entry, &tooltip_entry,
 					_("Battery"), &launch);
 	g_signal_connect(G_OBJECT(launch_entry), "changed",
 			G_CALLBACK(cb_launch_entry), NULL);
@@ -1251,7 +1251,7 @@ create_battery_tab(GtkWidget *tab_vbox)
 	vbox = gkrellm_gtk_framed_notebook_page(tabs, _("Info"));
 	text = gkrellm_gtk_scrolled_text_view(vbox, NULL,
 				GTK_POLICY_AUTOMATIC, GTK_POLICY_AUTOMATIC);
-	for (i = 0; i < sizeof(battery_info_text)/sizeof(gchar *); ++i)
+	for (size_t i = 0; i < G_N_ELEMENTS(battery_info_text); ++i)
 		gkrellm_gtk_text_view_append(text, _(battery_info_text[i]));
 	}
 
@@ -1264,7 +1264,7 @@ static GkrellmMonitor	monitor_battery =
 	create_battery_tab,		/* The config tab create function	*/
 	NULL,				/* Apply the config function		*/
 
-	save_battery_config,	/* Save user conifg			*/
+	save_battery_config,	/* Save user config			*/
 	load_battery_config,	/* Load user config			*/
 	BAT_CONFIG_KEYWORD,	/* config keyword			*/
 
