@@ -1,7 +1,7 @@
 /* GKrellM
 |  Copyright (C) 1999-2021 Bill Wilson
 |
-|  Author:  Bill Wilson    billw@gkrellm.net
+|  Author:  Bill Wilson
 |  Latest versions might be found at:  https://gkrellm.srcbox.net
 |
 |
@@ -287,8 +287,6 @@ create_calendar_panel(GtkWidget *vbox, gint first_create)
 		/* Help the motion out hack. If starting a move in host panel and mouse
 		|  jerks into the pclock/pcal drawing areas, we stop moving unless:
 		*/
-		extern void gkrellm_motion(GtkWidget *, GdkEventMotion *, gpointer);
-
 		g_signal_connect(G_OBJECT(pcal->drawing_area), "motion-notify-event",
 				G_CALLBACK(gkrellm_motion), NULL);
 
@@ -716,7 +714,6 @@ create_clock_tab(GtkWidget *tab_vbox)
 	{
 	GtkWidget	*tabs;
 	GtkWidget	*table, *vbox, *vbox1, *hbox, *label, *text;
-	gint		i;
 
 	tabs = gtk_notebook_new();
 	gtk_notebook_set_tab_pos(GTK_NOTEBOOK(tabs), GTK_POS_TOP);
@@ -805,7 +802,7 @@ create_clock_tab(GtkWidget *tab_vbox)
 	vbox = gkrellm_gtk_framed_notebook_page(tabs, _("Info"));
 	text = gkrellm_gtk_scrolled_text_view(vbox, NULL,
 				GTK_POLICY_AUTOMATIC, GTK_POLICY_AUTOMATIC);
-	for (i = 0; i < sizeof(clock_info_text)/sizeof(gchar *); ++i)
+	for (size_t i = 0; i < G_N_ELEMENTS(clock_info_text); ++i)
 		gkrellm_gtk_text_view_append(text, _(clock_info_text[i]));
 	g_signal_connect(G_OBJECT(cal_launch_entry), "changed",
 			G_CALLBACK(cb_launch_entry), GINT_TO_POINTER(1));
