@@ -1,7 +1,7 @@
 /* GKrellM
 |  Copyright (C) 1999-2021 Bill Wilson
 |
-|  Author:  Bill Wilson    billw@gkrellm.net
+|  Author:  Bill Wilson
 |  Latest versions might be found at:  https://gkrellm.srcbox.net
 |
 |
@@ -31,6 +31,11 @@
 |  as that of the covered work.
 */
 
+// FIXME: Remove hack that maps old GdkFont API to pango fonts.
+// These functions are referenced by old plugins. Removing it is binary incompatible.
+
+#if !defined(_WIN32) // Disable on win32, no known-working plugin needs it anymore
+
 #include <string.h>
 
 
@@ -85,3 +90,5 @@ gdk_string_extents(void *font_desc, const char *string,
 	if (d)
 		*d = y_ink + height - baseline;
 	}
+
+#endif
\ No newline at end of file
