@@ -1,7 +1,7 @@
 /* GKrellM
 |  Copyright (C) 1999-2021 Bill Wilson
 |
-|  Author:  Bill Wilson    billw@gkrellm.net
+|  Author:  Bill Wilson
 |  Latest versions might be found at:  https://gkrellm.srcbox.net
 |
 |
@@ -112,7 +112,11 @@ static GList	*fs_mon_list,
 				*mounts_list;
 static GList	*fstab_list;
 
-static gint		uid;
+#if defined(WIN32)
+static short uid; // nothing comparable available on windows
+#else
+static uid_t uid; // only real root is allowed to mount/umount always
+#endif
 
 static GkrellmFsGetMountsListFunc get_mounts_list;
 static GkrellmFsGetUsageFunc get_fsusage;
@@ -171,11 +175,12 @@ static gchar *remote_fs_types[]	=
 static gboolean
 setup_fs_interface(void)
     {
-#ifdef WIN32
-	uid = 0; /* nothing comparable available on windows */
+#if defined(WIN32)
+	uid = 0; // nothing comparable available on windows
 #else
-	uid = getuid();	/* only real root is allowed to mount/umount always */
+	uid = getuid(); // only real root is allowed to mount/umount always
 #endif
+
 	if (!get_fsusage && !_GK.client_mode && gkrellm_sys_fs_init())
 		{
 		get_fsusage = gkrellm_sys_fs_get_fsusage;
@@ -312,7 +317,6 @@ fs_is_mounted(FSmon *fs)
 	{
 	Mount	*m_fs, *m_mounted;
 	GList	*list;
-	gint	i;
 
 	fs->is_mounted = FALSE;
 	m_fs = &fs->mount;
@@ -323,7 +327,7 @@ fs_is_mounted(FSmon *fs)
 			continue;
 		fs->is_mounted = TRUE;
 		fs->is_nfs_fs = FALSE;
-		for (i = 0; i < (sizeof(remote_fs_types) / sizeof(gchar *)); ++i)
+		for (size_t i = 0; i < G_N_ELEMENTS(remote_fs_types); ++i)
 			{
 			if (!strcmp(m_mounted->type, remote_fs_types[i]))
 				{
@@ -357,39 +361,39 @@ static GkrellmSizeAbbrev	fs_binary_abbrev[] =
 	{ TiB_SIZE(100),	TiB_SIZE(1),	"%.1fT" }
 	};
 
-static gint
+static void
 format_fs_data(FSmon *fs, gchar *src_string, gchar *buf, gint size)
 	{
 	gint64		b, u, a;
 	gint		len;
 	gchar		*s;
 	gchar		tbuf[32], ubuf[32], abuf[32];
-	gfloat		bsize, val;
+	double		val;
 	GkrellmSizeAbbrev *tbl;
 	size_t		tbl_size;
 
 	if (!buf || size < 1)
-		return -1;
+		return;
 	--size;
 	*buf = '\0';
 	if (!src_string)
-		return -1;
+		return;
 
 	b = fs->blocks;
 	u = fs->blocks - fs->bfree;
 	a = fs->bavail;					/* Can be negative on BSD	*/
-	bsize = (gfloat) fs->bsize;
+	const double bsize = (double) fs->bsize;
 
 	tbl = binary_units ? &fs_binary_abbrev[0] : &fs_decimal_abbrev[0];
 	tbl_size = binary_units
 			? (sizeof(fs_binary_abbrev) / sizeof(GkrellmSizeAbbrev))
 			: (sizeof(fs_decimal_abbrev) / sizeof(GkrellmSizeAbbrev));
 
-	gkrellm_format_size_abbrev(tbuf, sizeof(tbuf), (gfloat) b * bsize,
+	gkrellm_format_size_abbrev(tbuf, sizeof(tbuf), (double) b * bsize,
 				tbl, tbl_size);
-	gkrellm_format_size_abbrev(ubuf, sizeof(ubuf), (gfloat) u * bsize,
+	gkrellm_format_size_abbrev(ubuf, sizeof(ubuf), (double) u * bsize,
 				tbl, tbl_size);
-	gkrellm_format_size_abbrev(abuf, sizeof(abuf), (gfloat) a * bsize,
+	gkrellm_format_size_abbrev(abuf, sizeof(abuf), (double) a * bsize,
 				tbl, tbl_size);
 
 	for (s = src_string; *s != '\0' && size > 0; ++s)
@@ -415,7 +419,7 @@ format_fs_data(FSmon *fs, gchar *src_string, gchar *buf, gint size)
 					break;
 				case 'U':
 					if (u + a > 0)
-						val = 100.0 * (gfloat) u / (gfloat) (u + a);
+						val = 100.0 * (double) u / (double) (u + a);
 					else
 						val = 0;
 					len = snprintf(buf, size, "%.0f%%", val);
@@ -425,7 +429,7 @@ format_fs_data(FSmon *fs, gchar *src_string, gchar *buf, gint size)
 					break;
 				case 'F':
 					if (u + a > 0)
-						val = 100.0 * (gfloat) a / (gfloat) (u + a);
+						val = 100.0 * (double) a / (double) (u + a);
 					else
 						val = 0;
 					len = snprintf(buf, size, "%.0f%%", val);
@@ -451,7 +455,6 @@ format_fs_data(FSmon *fs, gchar *src_string, gchar *buf, gint size)
 		buf += len;
 		}
 	*buf = '\0';
-	return u + 1;
 	}
 
   /* Draw the fs label or toggle the fs total blocks and blocks avail.
@@ -579,9 +582,8 @@ static void
 accumulate_pipe_gstring(FSmon *fs)
 	{
 	gchar	buf[512];
-	gint	n;
 
-	n = fread(buf, 1, sizeof(buf) - 1, fs->launch_mount.pipe);
+	size_t n = fread(buf, 1, sizeof(buf) - 1, fs->launch_mount.pipe);
 	buf[n] = '\0';
 	if (n > 0)
 		{
@@ -590,6 +592,7 @@ accumulate_pipe_gstring(FSmon *fs)
 		else
 			fs->pipe_gstring = g_string_new(buf);
 		}
+
 	if (feof(fs->launch_mount.pipe))
 		{
 		pclose(fs->launch_mount.pipe);
@@ -1034,7 +1037,7 @@ cb_panel_press(GtkWidget *widget, GdkEventButton *ev, FSmon *fs)
 		fs->mouse_entered = TRUE;
 		gkrellm_config_modified();
 		}
-	x_fs_motion = ev->x;
+	x_fs_motion = (int) ev->x;
 	fs_draw_decal_text(fs, 1);
 	gkrellm_draw_panel_layers(fs->panel);
 	fs_in_motion = fs;
@@ -1068,8 +1071,8 @@ cb_panel_motion(GtkWidget *widget, GdkEventButton *ev)
 	gkrellm_decal_scroll_text_get_size(d, &w, NULL);
 	if (w > d->w)
 		{
-		x_delta = ev->x - x_fs_motion;
-		x_fs_motion = ev->x;
+		x_delta = (int) ev->x - x_fs_motion;
+		x_fs_motion = (int) ev->x;
 		d->x_off += x_delta;
 		if (d->x_off < -w)
 			d->x_off = -w;
@@ -1275,7 +1278,6 @@ fs_create(GtkWidget *vbox, gint first_create)
 	{
 	GList	*list;
 	FSmon	*fs;
-	gint	i;
 
 	if (fs_main_vbox == NULL)
 		{
@@ -1289,11 +1291,13 @@ fs_create(GtkWidget *vbox, gint first_create)
 		secondary_monitors_shown = FALSE;
 		}
 	n_fs_monitors = 0;
-	for (i = 0, list = fs_mon_list; list; ++i, list = list->next)
+	int fs_monitor_index = 0;
+	for (list = fs_mon_list; list; list = list->next)
 		{
 		fs = (FSmon *)list->data;
 		fs_monitor_create(fs->secondary ? fs_secondary_vbox : fs_main_vbox,fs,
-					i, first_create);
+					fs_monitor_index, first_create);
+		++fs_monitor_index;
 		}
 	if (g_list_length(fs_mon_list) == 0)
 		gkrellm_spacers_hide(mon_fs);
@@ -1518,7 +1522,6 @@ enum
 
 static GtkTreeView		*treeview;
 static GtkTreeRowReference *row_reference;
-static GtkTreeSelection	*selection;
 
 static GtkWidget
 				*label_entry,
@@ -1665,13 +1668,12 @@ cb_alert_config(GkrellmAlert *ap, FSmon *fs)
 	FSmon			*fs_test;
 	GdkPixbuf       *pixbuf;
 	gchar           node[2];
-	gint            i;
 
 	if (!gkrellm_config_window_shown())
 		return;
 	model = gtk_tree_view_get_model(treeview);
 	pixbuf = ap->activated ? gkrellm_alert_pixbuf() : NULL;
-	for (i = 0; i < 2; ++i)
+	for (char i = 0; i < 2; ++i)
 		{
 		node[0] = '0' + i;      /* toplevel Primary or Secondary node */
 		node[1] = '\0';
@@ -1814,7 +1816,7 @@ reset_entries(gboolean level0)
 		gtk_entry_set_text(GTK_ENTRY(umount_entry), "");
 		}
 	change_row_reference(NULL, NULL);
-	gtk_tree_selection_unselect_all(selection);
+	gtk_tree_selection_unselect_all(gtk_tree_view_get_selection(treeview));
 	}
 
 static FSmon *
@@ -2419,7 +2421,7 @@ create_fs_panels_page(GtkWidget *vbox)
 
 	gtk_container_add(GTK_CONTAINER(scrolled), GTK_WIDGET(treeview));
 
-	selection = gtk_tree_view_get_selection(treeview);
+	GtkTreeSelection* selection = gtk_tree_view_get_selection(treeview);
 	gtk_tree_selection_set_mode(selection, GTK_SELECTION_SINGLE);
 	g_signal_connect(G_OBJECT(selection), "changed",
 				G_CALLBACK(cb_tree_selection_changed), NULL);
@@ -2513,7 +2515,6 @@ fs_tab_create(GtkWidget *tab_vbox)
 	GtkWidget		*tabs;
 	GtkWidget		*vbox, *vbox1;
 	GtkWidget		*text;
-	gint			i;
 
 	row_reference = NULL;
 	refresh_fstab_list();
@@ -2581,9 +2582,9 @@ fs_tab_create(GtkWidget *tab_vbox)
 	text = gkrellm_gtk_scrolled_text_view(vbox, NULL,
 				GTK_POLICY_AUTOMATIC, GTK_POLICY_AUTOMATIC);
 	if (mounting_supported && !_GK.client_mode)
-		for (i = 0; i < sizeof(fs_info_text0)/sizeof(gchar *); ++i)
+		for (size_t i = 0; i < G_N_ELEMENTS(fs_info_text0); ++i)
 			gkrellm_gtk_text_view_append(text, _(fs_info_text0[i]));
-	for (i = 0; i < sizeof(fs_info_text1)/sizeof(gchar *); ++i)
+	for (size_t i = 0; i < G_N_ELEMENTS(fs_info_text1); ++i)
 		gkrellm_gtk_text_view_append(text, _(fs_info_text1[i]));
 	}
 
