@@ -1,7 +1,7 @@
 /* GKrellM
 |  Copyright (C) 1999-2021 Bill Wilson
 |
-|  Author:  Bill Wilson    billw@gkrellm.net
+|  Author:  Bill Wilson
 |  Latest versions might be found at:  https://gkrellm.srcbox.net
 |
 |
@@ -1066,9 +1066,8 @@ save_inet_config(FILE *f)
 	InetMon		*in;
 	gchar		buf[128];
 	gchar		*l0, *l1;
-	gint		i;
 
-	for (i = 0, list = inet_mon_list; list; list = list->next, ++i)
+	for (list = inet_mon_list; list; list = list->next)
 		{
 		in = (InetMon *) list->data;
 		l0 = (*in->label0) ? in->label0: "NONE";
@@ -1409,7 +1408,6 @@ enum
 
 static GtkTreeView	*treeview;
 static GtkTreeRowReference *row_reference;
-static GtkTreeSelection	*selection;
 
 
 static GtkWidget	*label0_entry,
@@ -1531,7 +1529,7 @@ reset_entries(void)
 	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(data1_range_button), 0);
 
 	change_row_reference(NULL, NULL);
-	gtk_tree_selection_unselect_all(selection);
+	gtk_tree_selection_unselect_all(gtk_tree_view_get_selection(treeview));
 	}
 
 
@@ -1844,7 +1842,6 @@ create_inet_tab(GtkWidget *tab_vbox)
 	GtkCellRenderer	*renderer;
 	GList			*list;
 	InetMon			*in;
-	gint			i;
 
 	row_reference = NULL;
 
@@ -1995,7 +1992,7 @@ create_inet_tab(GtkWidget *tab_vbox)
 
 
 	gtk_container_add(GTK_CONTAINER(scrolled), GTK_WIDGET(treeview));
-	selection = gtk_tree_view_get_selection(treeview);
+	GtkTreeSelection* selection = gtk_tree_view_get_selection(treeview);
 	gtk_tree_selection_set_mode(selection, GTK_SELECTION_SINGLE);
 	g_signal_connect(G_OBJECT(selection), "changed",
 				G_CALLBACK(cb_tree_selection_changed), NULL);
@@ -2037,7 +2034,7 @@ create_inet_tab(GtkWidget *tab_vbox)
 				GTK_POLICY_AUTOMATIC, GTK_POLICY_AUTOMATIC);
 	gtk_widget_show(launch_vbox);
 	gtk_widget_realize(launch_vbox);
-	for (i = 0, list = inet_mon_list; list; list = list->next, ++i)
+	for (list = inet_mon_list; list; list = list->next)
 		{
 		in = (InetMon *) list->data;
 		add_launch_entry(launch_vbox, in);
@@ -2047,7 +2044,7 @@ create_inet_tab(GtkWidget *tab_vbox)
 	vbox = gkrellm_gtk_framed_notebook_page(tabs, _("Info"));
 	text = gkrellm_gtk_scrolled_text_view(vbox, NULL,
 				GTK_POLICY_AUTOMATIC, GTK_POLICY_AUTOMATIC);
-	for (i = 0; i < sizeof(inet_info_text)/sizeof(gchar *); ++i)
+	for (size_t i = 0; i < G_N_ELEMENTS(inet_info_text); ++i)
 		gkrellm_gtk_text_view_append(text, _(inet_info_text[i]));
 
 	reset_entries();
