@@ -1,7 +1,7 @@
 /* GKrellM
 |  Copyright (C) 1999-2021 Bill Wilson
 |
-|  Author:  Bill Wilson    billw@gkrellm.net
+|  Author:  Bill Wilson
 |  Latest versions might be found at:  https://gkrellm.srcbox.net
 |
 |
@@ -40,7 +40,7 @@
 
 
 struct GkrellmConfig	_GK;
-GkrellmTicks			GK;
+GKRELLM_API GkrellmTicks GK;
 
 struct
 	{
@@ -322,11 +322,9 @@ update_monitors(gpointer user_data)
 	for (list = gkrellm_monitor_list; list; list = list->next)
 		{
 		mon = (GkrellmMonitor *) list->data;
-		gkrellm_record_state(UPDATE_MONITOR, mon);
 		if (mon->update_monitor && mon->privat->enabled)
 			(*(mon->update_monitor))();
 		}
-	gkrellm_record_state(INTERNAL, NULL);
 	++GK.timer_ticks;
 
 	if (save_position_countdown > 0 && --save_position_countdown == 0)
@@ -566,8 +564,8 @@ gkrellm_motion(GtkWidget *widget, GdkEventMotion *ev, gpointer data)
 void
 gkrellm_menu_popup(void)
 	{
-            gtk_menu_popup(GTK_MENU(gtk_ui_manager_get_widget(ui_manager, "/popup")), NULL, NULL, NULL, NULL,
-					0, gtk_get_current_event_time());
+	gtk_menu_popup(GTK_MENU(gtk_ui_manager_get_widget(ui_manager, "/popup")),
+		NULL, NULL, NULL, NULL, 0, gtk_get_current_event_time());
 	}
 
 static void
@@ -1816,9 +1814,7 @@ usage(void)
 	gtk_dialog_run(GTK_DIALOG(dialog));
 	gtk_widget_destroy(dialog);
 #else
-	gint	i;
-
-	for (i = 0; i < (sizeof(usage_string) / sizeof(gchar *)); ++i)
+	for (size_t i = 0; i < G_N_ELEMENTS(usage_string); ++i)
 		g_print("%s", _(usage_string[i]));
 #endif
 	}
@@ -1883,7 +1879,6 @@ gkrellm_build(void)
 				}
 			if (mon->create_monitor && mon->privat->enabled)
 				{
-				gkrellm_record_state(CREATE_MONITOR, mon);
 				gtk_widget_show(mon->privat->vbox);
 				gtk_widget_show(mon->privat->main_vbox);
 				render_monitor_spacers(mon);
@@ -1891,7 +1886,6 @@ gkrellm_build(void)
 							mon->privat->created ? FALSE : TRUE);
 				mon->privat->created = TRUE;
 				}
-			gkrellm_record_state(INTERNAL, NULL);
 			}
 		}
 	create_frame_bottom(gtree.bottom_vbox);
@@ -1970,62 +1964,6 @@ _signal_quit(gint sig)
 	gkrellm_exit(1);
 	}
 
-void
-gkrellm_record_state(enum GkrellmState state, GkrellmMonitor *mon)
-	{
-	_GK.gkrellm_state = state;
-	_GK.active_monitor = mon;
-	}
-
-static void
-gkrellm_abort(gint sig)
-	{
-	gchar			*fault,
-					*state,
-					buf[512];
-	gboolean		do_xmessage = TRUE;
-	GkrellmMonitor	*mon 	= _GK.active_monitor;
-
-	if (sig == SIGSEGV)
-		fault = _("segmentation fault");
-	else if (sig == SIGFPE)
-		fault = _("floating point exception");
-	else
-		fault = _("aborted");
-
-	if (_GK.gkrellm_state == INITIALIZING)
-		state = _("initializing");
-	else if (_GK.gkrellm_state == INIT_MONITOR)
-		state = "init_monitor";
-	else if (_GK.gkrellm_state == CREATE_MONITOR)
-		state = "create_monitor";
-	else if (_GK.gkrellm_state == UPDATE_MONITOR)
-		state = "update_monitor";
-	else if (_GK.gkrellm_state == CREATE_CONFIG)
-		state = "create_config";
-	else if (_GK.gkrellm_state == LOAD_CONFIG)
-		state = "load_user_config";
-	else if (_GK.gkrellm_state == SAVE_CONFIG)
-		state = "save_user_config";
-	else if (_GK.gkrellm_state == APPLY_CONFIG)
-		state = "apply_config";
-	else
-		{
-		state = "?";
-		do_xmessage = FALSE;
-		}
-
-	// FIXME: xmessage is only available on X11
-	snprintf(buf, sizeof(buf), "xmessage gkrellm %s:  %s  (%s)", fault,
-				(mon && mon->name) ? mon->name : "", state);
-	g_warning("%s\n", buf + 9);
-	if (do_xmessage)
-		g_spawn_command_line_async(buf, NULL);
-
-	signal(SIGABRT, SIG_DFL);
-	abort();
-	}
-
 static void
 setup_signal_handler(void)
 	{
@@ -2086,10 +2024,6 @@ main(gint argc, gchar **argv)
 	gkrellm_current_tm = *(localtime(&_GK.start_time));
 
 	_GK.initialized = FALSE;
-	gkrellm_record_state(INITIALIZING, NULL);
-	signal(SIGFPE, gkrellm_abort);
-	signal(SIGSEGV, gkrellm_abort);
-	signal(SIGABRT, gkrellm_abort);
 
 	for (i = 1; i < argc; ++i)
 		{
