@@ -1,7 +1,7 @@
 /* GKrellM
 |  Copyright (C) 1999-2021 Bill Wilson
 |
-|  Author:  Bill Wilson    billw@gkrellm.net
+|  Author:  Bill Wilson
 |  Latest versions might be found at:  https://gkrellm.srcbox.net
 |
 |
@@ -62,8 +62,6 @@
 
 #define	DEFAULT_FORMAT	_("$t - $f free")
 
-#define MEG(x)	((gulong)(((x) + (1 << 19)) >> 20))
-
 typedef struct
 	{
 	GkrellmPanel *panel;
@@ -184,7 +182,7 @@ static gint		mem_pipe[PIPE_SIZE],
 				swap_pipe[PIPE_SIZE];
 static gint		force_update	= TRUE;
 
-gboolean
+static gboolean
 force_meminfo_update(void)
 	{
 	gint	i, force;
@@ -202,32 +200,43 @@ force_meminfo_update(void)
 	return force;
 	}
 
-static gint
+static GkrellmSizeAbbrev meminfo_abbrev[] =
+	{
+	{ MiB_SIZE(10),     MiB_SIZE(1),    "%.2fM" },
+	{ GiB_SIZE(1),      MiB_SIZE(1),    "%.0fM" },
+	{ GiB_SIZE(10),     GiB_SIZE(1),    "%.2fG" },
+	{ GiB_SIZE(100),    GiB_SIZE(1),    "%.1fG" },
+	{ TiB_SIZE(1),      GiB_SIZE(1),    "%.0fG" },
+	{ TiB_SIZE(10),     TiB_SIZE(1),    "%.2fT" },
+	{ TiB_SIZE(100),    TiB_SIZE(1),    "%.1fT" }
+	};
+
+static const ssize_t meminfo_abbrev_size =
+	sizeof(meminfo_abbrev) / sizeof(GkrellmSizeAbbrev);
+
+static void
 format_meminfo_data(MeminfoMeter *mm, gchar *src_string, gchar *buf, gint size)
 	{
-	gulong		t, u, f, ur, fr;
-	gchar		*s, *label;
-	gint		len;
-	gboolean	raw;
-
 	if (!buf || size < 1)
-		return -1;
+		return;
 	--size;
 	*buf = '\0';
 	if (!src_string)
-		return -1;
-	label = mm->label;
-	t = MEG(mm->total);
-	u = MEG(mm->used);
-	f = t - u;
+		return;
 
-	fr = MEG(mem.free);
-	ur = u + MEG(mem.shared + mem.buffers + mem.cached);
+	const char *label = mm->label;
 
-	for (s = src_string; *s != '\0' && size > 0; ++s)
+	const guint64 total_bytes = mm->total;
+	const guint64 used_bytes = mm->used;
+	const guint64 free_bytes = total_bytes - used_bytes;
+
+	const guint64 free_bytes_raw = mem.free;
+	const guint64 used_bytes_raw = used_bytes + mem.shared + mem.buffers + mem.cached;
+
+	for (const char *s = src_string; *s != '\0' && size > 0; ++s)
 		{
-		len = 1;
-		raw = FALSE;
+		int len = 1;
+		gboolean raw = FALSE;
 		if (*s == '$' && *(s + 1) != '\0')
 			{
 			if (*(s + 2) == 'r')  /* print raw free/used */
@@ -238,35 +247,59 @@ format_meminfo_data(MeminfoMeter *mm, gchar *src_string, gchar *buf, gint size)
 					len = snprintf(buf, size, "%s", label);
 					break;
 				case 't':
-					len = snprintf(buf, size, "%ldM", t);
+					len = gkrellm_format_size_abbrev(buf, size,
+						(double) total_bytes,
+						meminfo_abbrev, meminfo_abbrev_size);
 					break;
 				case 'u':
-					len = snprintf(buf, size, "%ldM", raw ? ur : u);
+					len = gkrellm_format_size_abbrev(buf, size,
+						(double) (raw ? used_bytes_raw : used_bytes),
+						meminfo_abbrev, meminfo_abbrev_size);
 					break;
 				case 'U':
-					if (t > 0)
-						len = snprintf(buf, size, "%ld%%",
-							100 * (raw ? ur : u) / t);
+					if (total_bytes > 0)
+						{
+						const unsigned int used_percent = 100ull *
+							(raw ? used_bytes_raw : used_bytes) / total_bytes;
+						len = snprintf(buf, size, "%u%%", used_percent);
+						}
 					break;
 				case 'f':
-					len = snprintf(buf, size, "%ldM", raw ? fr : f);
+					len = gkrellm_format_size_abbrev(buf, size,
+						(double) (raw ? free_bytes_raw : free_bytes),
+						meminfo_abbrev, meminfo_abbrev_size);
 					break;
 				case 'F':
-					if (t > 0)
-						len = snprintf(buf, size, "%ld%%",
-							100 * (raw ? fr : f) / t);
+					if (total_bytes > 0)
+						{
+						const unsigned int free_percent = 100ull *
+							(raw ? free_bytes_raw : free_bytes) / total_bytes;
+						len = snprintf(buf, size, "%u%%", free_percent);
+						}
 					break;
 				case 's':
 					if (mm == &mem)
-						len = snprintf(buf, size, "%ldM", MEG(mem.shared));
+						{
+						len = gkrellm_format_size_abbrev(buf, size,
+							(double) (mem.shared),
+							meminfo_abbrev, meminfo_abbrev_size);
+						}
 					break;
 				case 'b':
 					if (mm == &mem)
-						len = snprintf(buf, size, "%ldM",MEG(mem.buffers));
+						{
+						len = gkrellm_format_size_abbrev(buf, size,
+							(double) (mem.buffers),
+							meminfo_abbrev, meminfo_abbrev_size);
+						}
 					break;
 				case 'c':
 					if (mm == &mem)
-						len = snprintf(buf, size, "%ldM", MEG(mem.cached));
+						{
+						len = gkrellm_format_size_abbrev(buf, size,
+							(double) (mem.cached),
+							meminfo_abbrev, meminfo_abbrev_size);
+						}
 					break;
 				case 'H':
 						len = snprintf(buf, size, "%s",
@@ -291,7 +324,6 @@ format_meminfo_data(MeminfoMeter *mm, gchar *src_string, gchar *buf, gint size)
 		buf += len;
 		}
 	*buf = '\0';
-	return t + u + 1;		/* A way to know if decal text changed. */
 	}
 
 static gint
@@ -308,8 +340,8 @@ draw_decal_label(MeminfoMeter *mm, gint draw_to_screen)
 		gkrellm_decal_text_set_offset(d, mm->x_label, 0);
 		gkrellm_draw_decal_text(mm->panel, d, mm->label, 0);
 		}
-    else
-        {
+	else
+		{
 		ts_save = d->text_style;
 		d->text_style = *gkrellm_meter_alt_textstyle(mm->style_id);
 
@@ -355,6 +387,7 @@ static GkrellmSizeAbbrev	swap_blocks_abbrev[] =
 	{ MB_SIZE(20),		MB_SIZE(1),		"%.1fM" }
 	};
 
+static const size_t swap_blocks_abbrev_size = sizeof(swap_blocks_abbrev) / sizeof(GkrellmSizeAbbrev);
 
 static gchar    *text_format,
 				*text_format_locale;
@@ -362,31 +395,42 @@ static gchar    *text_format,
 static void
 format_chart_text(MeminfoChart *mc, gchar *buf, gint size)
 	{
-	GkrellmChart	*cp;
-	gchar	c, *s;
-	size_t	tbl_size;
-	gint	len, in_blocks, out_blocks, blocks;
-
 	--size;
 	*buf = '\0';
-	cp = mc->chart;
-	in_blocks = gkrellm_get_current_chartdata(mc->in_cd);
-	out_blocks = gkrellm_get_current_chartdata(mc->out_cd);
-	tbl_size = sizeof(swap_blocks_abbrev) / sizeof(GkrellmSizeAbbrev);
-	for (s = text_format_locale; *s != '\0' && size > 0; ++s)
+
+	GkrellmChart *cp = mc->chart;
+	const int in_blocks = gkrellm_get_current_chartdata(mc->in_cd);
+	const int out_blocks = gkrellm_get_current_chartdata(mc->out_cd);
+	for (const char *s = text_format_locale; *s != '\0' && size > 0; ++s)
 		{
-		len = 1;
+		int len = 1;
 		if (*s == '$' && *(s + 1) != '\0')
 			{
-			blocks = -1;
-			if ((c = *(s + 1)) == 'T')
-				blocks = in_blocks + out_blocks;
+			const char c = *(s + 1);
+			if (c == 'T')
+				{
+				len = gkrellm_format_size_abbrev(buf, (size_t) size,
+					(double) (in_blocks + out_blocks),
+					&swap_blocks_abbrev[0], swap_blocks_abbrev_size);
+				}
 			else if (c == 'M')
-				blocks = gkrellm_get_chart_scalemax(cp);
+				{
+				len = gkrellm_format_size_abbrev(buf, (size_t) size,
+					(double) gkrellm_get_chart_scalemax(cp),
+					&swap_blocks_abbrev[0], swap_blocks_abbrev_size);
+				}
 			else if (c == 'i')
-				blocks = in_blocks;
+				{
+				len = gkrellm_format_size_abbrev(buf, (size_t) size,
+					(double) in_blocks,
+					&swap_blocks_abbrev[0], swap_blocks_abbrev_size);
+				}
 			else if (c == 'o')
-				blocks = out_blocks;
+				{
+				len = gkrellm_format_size_abbrev(buf, (size_t) size,
+					(double) out_blocks,
+					&swap_blocks_abbrev[0], swap_blocks_abbrev_size);
+				}
 			else
 				{
 				*buf = *s;
@@ -396,9 +440,6 @@ format_chart_text(MeminfoChart *mc, gchar *buf, gint size)
 					++len;
 					}
 				}
-			if (blocks >= 0)
-				len = gkrellm_format_size_abbrev(buf, size, (gfloat) blocks,
-						&swap_blocks_abbrev[0], tbl_size);
 			++s;
 			}
 		else
@@ -1299,7 +1340,6 @@ create_meminfo_tab(GtkWidget *tab_vbox)
 	GtkWidget		*table;
 	GtkWidget		*hbox;
 	GtkWidget		*text, *label;
-	gint			i;
 
 	tabs = gtk_notebook_new();
 	gtk_notebook_set_tab_pos(GTK_NOTEBOOK(tabs), GTK_POS_TOP);
@@ -1438,7 +1478,7 @@ create_meminfo_tab(GtkWidget *tab_vbox)
 	vbox = gkrellm_gtk_framed_notebook_page(tabs, _("Info"));
 	text = gkrellm_gtk_scrolled_text_view(vbox, NULL,
 				GTK_POLICY_AUTOMATIC, GTK_POLICY_AUTOMATIC);
-	for (i = 0; i < sizeof(mem_info_text)/sizeof(gchar *); ++i)
+	for (size_t i = 0; i < G_N_ELEMENTS(mem_info_text); ++i)
 		gkrellm_gtk_text_view_append(text, _(mem_info_text[i]));
 	}
 
