@@ -1,7 +1,7 @@
 /* GKrellM
 |  Copyright (C) 1999-2021 Bill Wilson
 |
-|  Author:  Bill Wilson    billw@gkrellm.net
+|  Author:  Bill Wilson
 |  Latest versions might be found at:  https://gkrellm.srcbox.net
 |
 |
@@ -233,7 +233,7 @@ static NetMon *
 new_net(gchar *name)
 	{
 	NetMon	*net;
-	
+
 	net = g_new0(NetMon, 1);
 	net->name = g_strdup(name);
 	if (strcmp(name, "lo"))		/* lo is disabled by default */
@@ -673,14 +673,14 @@ stats_model_create(NetMon *net, NetStat *ns, gint n_stats)
 		{
 		if (i > 0 && !strncmp(ns->date, "---", 3))
 			continue;
-		gkrellm_format_size_abbrev(rx, sizeof(rx), (gfloat) ns->rx,
+		gkrellm_format_size_abbrev(rx, sizeof(rx), (double) ns->rx,
 					&stats_bytes_abbrev[0],
 					sizeof(stats_bytes_abbrev) / sizeof(GkrellmSizeAbbrev));
-		gkrellm_format_size_abbrev(tx, sizeof(tx), (gfloat) ns->tx,
+		gkrellm_format_size_abbrev(tx, sizeof(tx), (double) ns->tx,
 					&stats_bytes_abbrev[0],
 					sizeof(stats_bytes_abbrev) / sizeof(GkrellmSizeAbbrev));
 		gkrellm_format_size_abbrev(total, sizeof(total),
-					(gfloat) (ns->rx + ns->tx),
+					(double) (ns->rx + ns->tx),
 					&stats_bytes_abbrev[0],
 					sizeof(stats_bytes_abbrev) / sizeof(GkrellmSizeAbbrev));
 		minutes = ns->connect_time / 60;
@@ -1344,12 +1344,12 @@ format_net_data(NetMon *net, gchar *src_string, gchar *buf, gint size)
 					}
 				}
 			if (bytes >= 0)
-				len = gkrellm_format_size_abbrev(buf, size, (gfloat) bytes,
+				len = gkrellm_format_size_abbrev(buf, (size_t) size, (double) bytes,
 					&current_bytes_abbrev[0],
 					sizeof(current_bytes_abbrev) / sizeof(GkrellmSizeAbbrev));
 			else if (fbytes >= 0)
 				{
-				len = gkrellm_format_size_abbrev(buf, size, (gfloat) fbytes,
+				len = gkrellm_format_size_abbrev(buf, (size_t) size, (double) fbytes,
 					&total_bytes_abbrev[0],
 					sizeof(total_bytes_abbrev) /sizeof(GkrellmSizeAbbrev));
 				if (!day && !week && !month)
@@ -1534,9 +1534,9 @@ net_chart_reorder(NetMon *new_net)
 	{
 	NetMon		*net;
 	GList		*list;
-	gint		i;
 
-	for (i = 0, list = net_mon_list; list; list = list->next)
+	int i = 0;
+	for (list = net_mon_list; list; list = list->next)
 		{
 		net = (NetMon *) list->data;
 		if (net->parent_vbox != new_net->parent_vbox)
@@ -1732,19 +1732,27 @@ gkrellm_net_save_data(void)
 
 		fputs("[daily]\n", f);
 		for (i = 0; i < N_DAY_STATS; ++i)
+			{
 			fprintf(f, "\"%s\" %.0f %.0f %d\n", net->day_stats[i].date,
 					net->day_stats[i].rx, net->day_stats[i].tx,
 					net->day_stats[i].connect_time);
+			}
+
 		fputs("[weekly]\n", f);
 		for (i = 0; i < N_WEEK_STATS; ++i)
+			{
 			fprintf(f, "\"%s\" %.0f %.0f %d\n", net->week_stats[i].date,
 					net->week_stats[i].rx, net->week_stats[i].tx,
 					net->week_stats[i].connect_time);
+			}
+
 		fputs("[monthly]\n", f);
-			for (i = 0; i < N_MONTH_STATS; ++i)
-		fprintf(f, "\"%s\" %.0f %.0f %d\n", net->month_stats[i].date,
+		for (i = 0; i < N_MONTH_STATS; ++i)
+			{
+			fprintf(f, "\"%s\" %.0f %.0f %d\n", net->month_stats[i].date,
 					net->month_stats[i].rx, net->month_stats[i].tx,
 					net->month_stats[i].connect_time);
+			}
 		fclose(f);
 		}
 	}
@@ -3068,7 +3076,6 @@ create_net_tab(GtkWidget *tab_vbox)
 	NetMon			*net;
 	TimerType		*tt;
 	gchar			buf[256];
-	gint			i;
 
 	tabs = gtk_notebook_new();
 	gtk_notebook_set_tab_pos(GTK_NOTEBOOK(tabs), GTK_POS_TOP);
@@ -3256,10 +3263,10 @@ create_net_tab(GtkWidget *tab_vbox)
 				GTK_POLICY_AUTOMATIC, GTK_POLICY_AUTOMATIC);
 #if !defined(WIN32)
 	if (!_GK.client_mode)
-		for (i = 0; i < sizeof(net_info_text0)/sizeof(gchar *); ++i)
+		for (size_t i = 0; i < G_N_ELEMENTS(net_info_text0); ++i)
 			gkrellm_gtk_text_view_append(text, _(net_info_text0[i]));
 #endif
-	for (i = 0; i < sizeof(net_info_text1)/sizeof(gchar *); ++i)
+	for (size_t i = 0; i < G_N_ELEMENTS(net_info_text1); ++i)
 		gkrellm_gtk_text_view_append(text, _(net_info_text1[i]));
 	}
 
