@@ -1,8 +1,8 @@
 /* GKrellM
-|  Copyright (C) 1999-2019 Bill Wilson
+|  Copyright (C) 1999-2021 Bill Wilson
 |
-|  Author:  Bill Wilson    billw@gkrellm.net
-|  Latest versions might be found at:  http://gkrellm.net
+|  Author:  Bill Wilson
+|  Latest versions might be found at:  https://gkrellm.srcbox.net
 |
 |
 |  GKrellM is free software: you can redistribute it and/or modify it
@@ -74,10 +74,10 @@ gkrellm_clone_pixmap(GdkPixmap **dest, GdkPixmap **src)
 			gkrellm_free_pixmap(dest);
 		}
 	if (!*dest)
-		*dest = gdk_pixmap_new(gkrellm_get_top_window()->window,
+		*dest = gdk_pixmap_new(gtk_widget_get_window(gkrellm_get_top_window()),
 					w_src, h_src, -1);
 	gdk_draw_drawable(*dest, _GK.draw1_GC, *src, 0, 0, 0, 0, w_src, h_src);
-	return TRUE;	
+	return TRUE;
 	}
 
 gboolean
@@ -100,10 +100,10 @@ gkrellm_clone_bitmap(GdkBitmap **dest, GdkBitmap **src)
 			gkrellm_free_bitmap(dest);
 		}
 	if (!*dest)
-		*dest = gdk_pixmap_new(gkrellm_get_top_window()->window,
+		*dest = gdk_pixmap_new(gtk_widget_get_window(gkrellm_get_top_window()),
 					w_src, h_src, 1);
 	gdk_draw_drawable(*dest, _GK.bit1_GC, *src, 0, 0, 0, 0, w_src, h_src);
-	return TRUE;	
+	return TRUE;
 	}
 
 static void
@@ -123,7 +123,7 @@ gboolean
 gkrellm_scale_pixbuf_to_pixmap(GdkPixbuf *src_pixbuf, GdkPixmap **pixmap,
 			GdkBitmap **mask, gint w_dst, gint h_dst)
 	{
-	GdkWindow		*window = gkrellm_get_top_window()->window;
+	GdkWindow		*window = gtk_widget_get_window(gkrellm_get_top_window());
 	GdkPixbuf		*dst_pixbuf;
 	gint			w_src, h_src;
 	gboolean		has_alpha;
@@ -298,19 +298,19 @@ gkrellm_scale_piximage_to_pixbuf(GkrellmPiximage *piximage,
 			b.left, dst_height,
 			0, (double) (b.top * -v_scale + b.top),
 			1.0, v_scale, interp_type);
-				
+
 	if (b.right > 0 && dst_height > 0)	/* right border */
 		gdk_pixbuf_scale(src_pixbuf, dst_pixbuf, w_dst - b.right, b.top,
 			b.right, dst_height,
 			(double) (w_dst - w_src), (double) (b.top * -v_scale + b.top),
 			1.0, v_scale, interp_type);
-				
+
 	if (b.top > 0 && dst_width > 0)	/* top border */
 		gdk_pixbuf_scale(src_pixbuf, dst_pixbuf, b.left, 0,
 			dst_width, b.top,
 			(double) (b.left * -h_scale + b.left), 0,
 			h_scale, 1.0, interp_type);
-				
+
 	if (b.bottom > 0 && dst_width > 0)	/* bottom border */
 		gdk_pixbuf_scale(src_pixbuf, dst_pixbuf, b.left, h_dst - b.bottom,
 			dst_width, b.bottom,
@@ -331,7 +331,7 @@ gboolean
 gkrellm_scale_piximage_to_pixmap(GkrellmPiximage *piximage, GdkPixmap **pixmap,
 			GdkBitmap **mask, gint w_dst, gint h_dst)
 	{
-	GdkWindow		*window = gkrellm_get_top_window()->window;
+	GdkWindow		*window = gtk_widget_get_window(gkrellm_get_top_window());
 	GdkPixbuf		*src_pixbuf, *dst_pixbuf;
 	gint			w_src, h_src;
 	gboolean		has_alpha;
@@ -436,7 +436,7 @@ gboolean
 gkrellm_scale_theme_background(GkrellmPiximage *piximage, GdkPixmap **pixmap,
 			GdkBitmap **mask, gint w_dst, gint h_dst)
 	{
-	GdkWindow		*window = gkrellm_get_top_window()->window;
+	GdkWindow		*window = gtk_widget_get_window(gkrellm_get_top_window());
 	GdkPixbuf		*src_pixbuf, *sub_pixbuf, *pixbuf;
 	GdkInterpType	interp_type;
 	GkrellmBorder	bdr;
@@ -682,7 +682,11 @@ gkrellm_piximage_new_from_inline(const guint8 *data, gboolean copy_pixels)
 	width  = big_endian_uint(d + 16);
 	height = big_endian_uint(d + 20);
 
+#if GLIB_CHECK_VERSION(2, 68, 0)
+	pixels = g_memdup2((gconstpointer)(d + 24), height * stride);
+#else
 	pixels = g_memdup((gconstpointer)(d + 24), height * stride);
+#endif
 
 	pixbuf = gdk_pixbuf_new_from_data(pixels,
 				GDK_COLORSPACE_RGB, TRUE, 8, width, height, stride,
