@@ -1,7 +1,7 @@
 /* GKrellM
 |  Copyright (C) 1999-2021 Bill Wilson
 |
-|  Author:  Bill Wilson    billw@gkrellm.net
+|  Author:  Bill Wilson
 |  Latest versions might be found at:  https://gkrellm.srcbox.net
 |
 |
@@ -89,7 +89,8 @@ static GList	*sensor_list	= NULL;
 
 static GList	*temp_order_list,	/* For ordering from the config. */
 				*fan_order_list,
-				*volt_order_list;
+				*volt_order_list,
+				*power_order_list;
 
 static gboolean	using_new_config,
 				need_disk_temperature_update;
@@ -97,6 +98,7 @@ static gboolean	using_new_config,
 static GkrellmSensorsGetTempFunc get_temperature;
 static GkrellmSensorsGetFanFunc get_fan;
 static GkrellmSensorsGetVoltFunc get_voltage;
+static GkrellmSensorsGetPowerFunc get_power;
 
 static void read_sensors_config(void);
 static GkrellmSensorsConfigMigrateFunc config_migrate;
@@ -107,12 +109,14 @@ static gint		sensor_config_sysdep_private;
 
 void
 gkrellm_sensors_client_divert(GkrellmSensorsGetTempFunc get_temp_func,
-			GkrellmSensorsGetFanFunc get_fan_func,
-			GkrellmSensorsGetVoltFunc get_volt_func)
+		GkrellmSensorsGetFanFunc get_fan_func,
+		GkrellmSensorsGetVoltFunc get_volt_func,
+		GkrellmSensorsGetPowerFunc get_power_func)
 	{
 	get_temperature = get_temp_func;
 	get_fan = get_fan_func;
 	get_voltage = get_volt_func;
+	get_power = get_power_func;
 	}
 
 void
@@ -132,6 +136,7 @@ setup_sensor_interface(void)
 		get_temperature = gkrellm_sys_sensors_get_temperature;
 		get_fan = gkrellm_sys_sensors_get_fan;
 		get_voltage = gkrellm_sys_sensors_get_voltage;
+		get_power = gkrellm_sys_sensors_get_power;
 		}
 	return get_temperature ? TRUE : FALSE;
 	}
@@ -153,7 +158,7 @@ gkrellm_sensors_add_sensor(gint type, gchar *sensor_path, gchar *id_name,
 	Sensor	*sensor;
 	gchar	*r;
 
-	if (!id_name || !*id_name || type < 0 || type > 2)
+	if (!id_name || !*id_name || type < 0 || type > SENSOR_POWER)
 		return NULL;
 
 	sensor = g_new0(Sensor, 1);
@@ -214,6 +219,9 @@ read_sensors_thread(void *data)
 		if (sensor->type == SENSOR_VOLTAGE && get_voltage)
 			(*get_voltage)(sensor->path, sensor->id,
 				sensor->iodev, sensor->inter, &sensor->raw_value);
+		if (sensor->type == SENSOR_POWER && get_power)
+			(*get_power)(sensor->path, sensor->id,
+				sensor->iodev, sensor->inter, &sensor->raw_value);
 		}
 	thread_busy = FALSE;
 	return NULL;
@@ -231,7 +239,7 @@ run_sensors_thread(void)
 	g_thread_unref(gth);
 	}
 
-  /* Sort so that sensors are ordered: temp, fan, voltage.
+  /* Sort so that sensors are ordered: temp, fan, voltage, power.
   */
 static gint
 strcmp_sensor_path(Sensor *s1, Sensor *s2)
@@ -246,6 +254,11 @@ strcmp_sensor_path(Sensor *s1, Sensor *s2)
 	if (s1->type != SENSOR_FAN && s2->type == SENSOR_FAN)
 		return 1;
 
+	if (s1->type == SENSOR_VOLTAGE && s2->type != SENSOR_VOLTAGE)
+		return -1;
+	if (s1->type != SENSOR_VOLTAGE && s2->type == SENSOR_VOLTAGE)
+		return 1;
+
 	return strcmp(s1->id_name, s2->id_name);
 	}
 
@@ -258,6 +271,8 @@ append_sensor_to_order_list(Sensor *sr)
 		fan_order_list = g_list_append(fan_order_list, sr);
 	else if (sr->type == SENSOR_VOLTAGE)
 		volt_order_list = g_list_append(volt_order_list, sr);
+	else if (sr->type == SENSOR_POWER)
+		power_order_list = g_list_append(power_order_list, sr);
 	}
 
 
@@ -377,7 +392,7 @@ gkrellm_sensor_draw_temperature_decal(GkrellmPanel *p, GkrellmDecal *d,
 		w = gkrellm_gdk_string_width(d->text_style.font, buf)
 				+ d->text_style.effect;
 		}
-	
+
 	d->x_off = d->w - w;
 	if (d->x_off < 0)
 		d->x_off = 0;
@@ -461,8 +476,10 @@ cb_command_process(GkrellmAlert *alert, gchar *src, gchar *buf, gint size,
 					fmt = "%.0f";
 				else if (sensor->type == SENSOR_TEMPERATURE)
 					fmt = "%.1f";
-				else				/* SENSOR_VOLTAGE */
+				else if (sensor->type == SENSOR_VOLTAGE)
 					fmt = "%.2f";
+				else				/* SENSOR_POWER */
+					fmt = "%.3f";
 				len = snprintf(buf, size, fmt, sensor->value);
 				}
 			else if (c == 'l' || c == 'L')
@@ -527,7 +544,7 @@ sensor_read_temperature(Sensor *sensor, gfloat *temp, gchar *units)
 		{
 		if (show_units)
 			*units = units_fahrenheit ? 'F':'C';
-	   	else
+		else
 			*units = '\0';
 		}
 	if (sensor)
@@ -620,6 +637,31 @@ gkrellm_sensor_read_voltage(gpointer sr, gfloat *voltage)
 	return sensor_read_voltage((Sensor *) sr, voltage);
 	}
 
+static gboolean
+sensor_read_power(Sensor *sensor, gfloat *power)
+	{
+	gfloat		p = 0;
+	gboolean	found_power = FALSE;
+
+	if (sensor && get_power)
+		{
+		found_power = thread_data_valid ? TRUE
+			: (*get_power)(sensor->path, sensor->id,
+					sensor->iodev, sensor->inter, &sensor->raw_value);
+		}
+	if (found_power && sensor)
+		{
+		p = sensor->raw_value * sensor->factor + sensor->offset;
+		sensor->value = p;
+		sensor->value_valid = TRUE;
+		if (sensor->alert)
+			gkrellm_check_alert(sensor->alert, p);
+		}
+	if (power)
+		*power = p;
+	return found_power;
+	}
+
 /* =================================================================== */
 /* The sensors monitor */
 
@@ -641,6 +683,7 @@ static void		sensor_reset_optionmenu(Sensor *sensor);
 #define DO_TEMP	1
 #define	DO_FAN	1
 #define	DO_VOLT	1
+#define	DO_POWER	1
 
 typedef struct
 	{
@@ -654,17 +697,20 @@ typedef struct
 static GtkWidget
 				*temp_vbox,
 				*fan_vbox,
-				*volt_vbox;
+				*volt_vbox,
+				*power_vbox;
 
 static GList	*volt_list,
 				*temperature_list,
 				*fan_list,
+				*power_list,
 				*disk_temperature_list;
 
 static GkrellmPanel
 				*pVolt,
 				*pTemp,
-				*pFan;
+				*pFan,
+				*pPower;
 
 static gint		style_id;
 static gint		volt_mon_width,
@@ -791,7 +837,7 @@ gkrellm_sensors_interface_remove(gint _interface)
 				}
 			}
 		}
-	while (removed_one);		
+	while (removed_one);
 	}
 
 static void
@@ -842,7 +888,7 @@ add_sensor_monitor(Sensor *sr, GkrellmPanel **p, GList **smon_list)
 	}
 
 static void
-make_sensor_monitor_lists(gboolean do_temp, gboolean do_fan, gboolean do_volt)
+make_sensor_monitor_lists(gboolean do_temp, gboolean do_fan, gboolean do_volt, gboolean do_power)
 	{
 	GList	*list;
 	Sensor	*sr;
@@ -857,6 +903,8 @@ make_sensor_monitor_lists(gboolean do_temp, gboolean do_fan, gboolean do_volt)
 		gkrellm_free_glist_and_data(&fan_list);
 	if (do_volt)
 		gkrellm_free_glist_and_data(&volt_list);
+	if (do_power)
+		gkrellm_free_glist_and_data(&power_list);
 
 	for (list = sensor_list; list; list = list->next)
 		{
@@ -871,6 +919,8 @@ make_sensor_monitor_lists(gboolean do_temp, gboolean do_fan, gboolean do_volt)
 				sr->vref = lookup_vref(sr, sr->vref_name);
 			add_sensor_monitor(sr, &pVolt, &volt_list);
 			}
+		if (do_power && sr->type == SENSOR_POWER)
+			add_sensor_monitor(sr, &pPower, &power_list);
 		}
 	}
 
@@ -1049,7 +1099,7 @@ layout_volt_decals(GkrellmPanel *p, GkrellmStyle *style)
 		cols = n;;
 	volt_mon_width = w / cols;		/* spread them out */
 	x = (w - cols * volt_mon_width) / 2 + m->left;
-		
+
 	gkrellm_get_top_bottom_margins(style, &y, NULL);
 	c = 0;
 	for (list = volt_list; list; list = list->next)
@@ -1105,7 +1155,7 @@ update_disk_temperatures(void)
 			}
 		}
 	if (display_failed)
-		gkrellm_sensors_rebuild(TRUE, FALSE, FALSE);
+		gkrellm_sensors_rebuild(TRUE, FALSE, FALSE, FALSE);
 	}
 
   /* Squeeze name decal text into a smaller font if it would overlap the
@@ -1262,6 +1312,36 @@ draw_voltages(Sensor *s, gint do_names)
 	gkrellm_draw_panel_layers(pVolt);
 	}
 
+static void
+draw_power_sensors(Sensor *sensor, gboolean force_draw)
+	{
+	GList		*list;
+	SensorMon	*smon;
+	gchar		*name, buf[32];
+	gfloat		p;
+
+	if (!pPower)
+		return;
+	for (list = power_list; list; list = list->next)
+		{
+		smon = (SensorMon *) list->data;
+		sensor = smon->sensor;
+		if (smon->name_decal)
+			{
+			name = name_text_fit(sensor, smon->name_decal, smon->sensor_decal);
+			gkrellm_draw_decal_markup(pPower, smon->name_decal, name);
+			g_free(name);
+			}
+		if (smon->sensor_decal)
+			{
+			sensor_read_power(sensor, &p);
+			snprintf(buf, sizeof(buf), "%.1fW", p);
+			gkrellm_draw_decal_text(pPower, smon->sensor_decal, buf, -1);
+			}
+		}
+	gkrellm_draw_panel_layers(pPower);
+	}
+
 static void
 update_sensors(void)
 	{
@@ -1282,6 +1362,7 @@ update_sensors(void)
 	draw_temperatures(FALSE);
 	draw_fans(FALSE);
 	draw_voltages(NULL, FALSE);
+	draw_power_sensors(NULL, FALSE);
 	update_disk_temperatures();
 	first_time_done = TRUE;
 	}
@@ -1489,7 +1570,7 @@ make_volt_panel(GtkWidget *vbox, gint first_create)
 	style = gkrellm_meter_style(style_id);
 	make_volt_decals(pVolt, style);
 	layout_volt_decals(pVolt, style);
-	
+
 	gkrellm_panel_configure(pVolt, NULL, style);
 
 	/* Make the bottom margin reference against the bottom volt decals
@@ -1512,9 +1593,62 @@ make_volt_panel(GtkWidget *vbox, gint first_create)
 	draw_voltages(NULL, TRUE);
 	}
 
+static void
+make_power_panel(GtkWidget *vbox, gboolean first_create)
+	{
+	GkrellmStyle	*style;
+	GkrellmMargin	*m;
+	GkrellmTextstyle *ts_name, *ts_sensor;
+	GList			*list;
+	SensorMon		*smon = NULL;
+	Sensor			*sensor;
+	GkrellmDecal	*d;
+	gchar			*format;
+	gint			y;
+
+	if (!pPower)
+		return;
+	style = gkrellm_meter_style(style_id);
+	m = gkrellm_get_style_margins(style);
+	format = "888.8W";
+	assign_textstyles(power_list, &ts_name, &ts_sensor, format);
+	gkrellm_get_top_bottom_margins(style, &y, NULL);
+	y += bezel_style->border.top;
+	for (list = power_list; list; list = list->next)
+		{
+		smon = (SensorMon *) list->data;
+		sensor = smon->sensor;
+		d = gkrellm_create_decal_text(pPower, format,
+				ts_sensor, style, -1, y, 0);
+		d->x = gkrellm_chart_width() - d->w - m->right - 1;
+		smon->sensor_decal = d;
+
+		smon->name_decal = gkrellm_create_decal_text(pPower,
+					sensor->name_locale, ts_name, style, -1, y, 0);
+		y = adjust_decal_positions(smon);
+		gkrellm_reset_alert_soft(sensor->alert);
+		}
+	g_free(ts_name);
+	g_free(ts_sensor);
+	gkrellm_panel_configure(pPower, NULL, style);
+	if (smon && smon->sensor_decal->y + smon->sensor_decal->h >
+		smon->name_decal->y + smon->name_decal->h - bezel_style->border.bottom
+	   )
+		gkrellm_panel_configure_add_height(pPower, bezel_style->border.bottom);
+	gkrellm_panel_create(vbox, mon_sensors, pPower);
+	draw_bezels(pPower, power_list, 0, 0, 1);
+	if (first_create)
+		{
+		g_signal_connect(G_OBJECT(pPower->drawing_area), "expose-event",
+				G_CALLBACK(expose_event), pPower);
+		g_signal_connect(G_OBJECT(pPower->drawing_area), "button-press-event",
+				G_CALLBACK(cb_panel_press), pPower);
+		}
+	draw_power_sensors(NULL, TRUE);
+	}
 
 static void
-destroy_sensors_monitor(gboolean do_temp, gboolean do_fan, gboolean do_volt)
+destroy_sensors_monitor(gboolean do_temp, gboolean do_fan, gboolean do_volt, gboolean do_power)
 	{
 	if (do_temp)
 		{
@@ -1531,13 +1665,18 @@ destroy_sensors_monitor(gboolean do_temp, gboolean do_fan, gboolean do_volt)
 		gkrellm_panel_destroy(pVolt);
 		pVolt = NULL;
 		}
+	if (do_power)
+		{
+		gkrellm_panel_destroy(pPower);
+		pPower = NULL;
+		}
 	}
 
 static void
-create_sensors_monitor(gboolean do_temp, gboolean do_fan, gboolean do_volt,
-			gboolean first_create)
+create_sensors_monitor(gboolean do_temp, gboolean do_fan, gboolean do_volt, gboolean do_power,
+		gboolean first_create)
 	{
-	make_sensor_monitor_lists(do_temp, do_fan, do_volt);
+	make_sensor_monitor_lists(do_temp, do_fan, do_volt, do_power);
 	if (do_temp && temperature_list)
 		{
 		if (!pTemp)
@@ -1556,17 +1695,23 @@ create_sensors_monitor(gboolean do_temp, gboolean do_fan, gboolean do_volt,
 			pVolt = gkrellm_panel_new0();
 		make_volt_panel(volt_vbox, first_create);
 		}
-	if (temperature_list || fan_list || volt_list)
+	if (do_power && power_list)
+		{
+		if (!pPower)
+			pPower = gkrellm_panel_new0();
+		make_power_panel(power_vbox, first_create);
+		}
+	if (temperature_list || fan_list || volt_list || power_list)
 		gkrellm_spacers_show(mon_sensors);
 	else
 		gkrellm_spacers_hide(mon_sensors);
 	}
 
 void
-gkrellm_sensors_rebuild(gboolean do_temp, gboolean do_fan, gboolean do_volt)
+gkrellm_sensors_rebuild(gboolean do_temp, gboolean do_fan, gboolean do_volt, gboolean do_power)
 	{
-	destroy_sensors_monitor(do_temp, do_fan, do_volt);
-	create_sensors_monitor(do_temp, do_fan, do_volt, TRUE);
+	destroy_sensors_monitor(do_temp, do_fan, do_volt, do_power);
+	create_sensors_monitor(do_temp, do_fan, do_volt, do_power, TRUE);
 	}
 
 static void
@@ -1591,6 +1736,10 @@ create_sensors(GtkWidget *vbox, gint first_create)
 		gtk_box_pack_start(GTK_BOX(vbox), volt_vbox, FALSE, FALSE, 0);
 		gtk_widget_show(volt_vbox);
 
+		power_vbox = gtk_vbox_new(FALSE, 0);
+		gtk_box_pack_start(GTK_BOX(vbox), power_vbox, FALSE, FALSE, 0);
+		gtk_widget_show(power_vbox);
+
 		bezel_style = gkrellm_style_new0();
 		}
 	else		/* To be done after disk panels created */
@@ -1603,7 +1752,7 @@ create_sensors(GtkWidget *vbox, gint first_create)
 	|      THEME_DIR/sensors/bg_volt.png
 	|  and for a border for it from the gkrellmrc in the format:
 	|      set_piximage_border sensors_bg_volt l,r,t,b
-	| There is no default for bg_volt image, ie it may end up being NULL. 
+	| There is no default for bg_volt image, ie it may end up being NULL.
 	*/
 	xpm = gkrellm_using_default_theme() ? bg_volt_xpm : NULL;
 	if (bezel_piximage)
@@ -1613,7 +1762,7 @@ create_sensors(GtkWidget *vbox, gint first_create)
 	if (!gkrellm_set_gkrellmrc_piximage_border("sensors_bg_volt", bezel_piximage, bezel_style))
 		bezel_style->border = default_bezel_border;
 
-	create_sensors_monitor(DO_TEMP, DO_FAN, DO_VOLT, first_create);
+	create_sensors_monitor(DO_TEMP, DO_FAN, DO_VOLT, DO_POWER, first_create);
 	}
 
   /* FIXME: monitor_sensors and monitor_config_sensors should be combined,
@@ -1706,6 +1855,10 @@ create_sensor_alert(Sensor *s)
 		s->alert = gkrellm_alert_create(NULL, s->name,
 				_("Sensor Fan RPM Limits"),
 				FALSE, TRUE, TRUE, 20000, 0, 100, 1000, 0);
+	else if (s->type == SENSOR_POWER)
+		s->alert = gkrellm_alert_create(NULL, s->name,
+				_("Sensor Power Limits"),
+				TRUE, TRUE, TRUE, 500, 0, 0.1, 10.0, 1);
 	else
 		return;
 	gkrellm_alert_delay_config(s->alert, 5, 60, 0);
@@ -1953,6 +2106,7 @@ read_sensors_config(void)
 	sensor_list = temp_order_list;
 	sensor_list = g_list_concat(sensor_list, fan_order_list);
 	sensor_list = g_list_concat(sensor_list, volt_order_list);
+	sensor_list = g_list_concat(sensor_list, power_order_list);
 	}
 
 enum
@@ -1969,7 +2123,6 @@ enum
 static GtkTreeModel			*sensor_model;
 static GtkTreeView			*treeview;
 static GtkTreeRowReference	*row_reference;
-static GtkTreeSelection		*selection;
 
 
 static GtkWidget	*optionmenu;
@@ -2058,6 +2211,13 @@ create_model(void)
 				VISIBLE_COLUMN, FALSE,
 				-1);
 	append_sensors_to_model(tree, &citer, &iter, SENSOR_VOLTAGE);
+
+	gtk_tree_store_append(tree, &iter, NULL);
+	gtk_tree_store_set(tree, &iter,
+				NAME_COLUMN, _("Power"),
+				VISIBLE_COLUMN, FALSE,
+				-1);
+	append_sensors_to_model(tree, &citer, &iter, SENSOR_POWER);
 	return GTK_TREE_MODEL(tree);
 	}
 
@@ -2226,7 +2386,7 @@ cb_drag_end(GtkWidget *widget, GdkDragContext *context, gpointer data)
 	dest_iface->row_drop_possible = original_row_drop_possible;
 
 	change_row_reference(NULL, NULL);
-	gtk_tree_selection_unselect_all(selection);
+	gtk_tree_selection_unselect_all(gtk_tree_view_get_selection(treeview));
 
 	g_list_free(sensor_list);
 	sensor_list = NULL;
@@ -2254,10 +2414,10 @@ cb_drag_end(GtkWidget *widget, GdkDragContext *context, gpointer data)
 	dragged_sensor = NULL;
 
 	if (type < 0)
-		gkrellm_sensors_rebuild(DO_TEMP, DO_FAN, DO_VOLT);
+		gkrellm_sensors_rebuild(DO_TEMP, DO_FAN, DO_VOLT, DO_POWER);
 	else
 		gkrellm_sensors_rebuild(type == SENSOR_TEMPERATURE,
-				type == SENSOR_FAN, type == SENSOR_VOLTAGE);
+				type == SENSOR_FAN, type == SENSOR_VOLTAGE, type == SENSOR_POWER);
 
 	return FALSE;
 	}
@@ -2323,7 +2483,7 @@ cb_location_menu(GtkComboBox *om, gpointer data)
 			   )
 				s->location = SENSOR_PANEL_LOCATION;	/* is being replaced */
 			}
-	gkrellm_sensors_rebuild(DO_TEMP, DO_FAN, FALSE);
+	gkrellm_sensors_rebuild(DO_TEMP, DO_FAN, FALSE, FALSE);
 
 	if (sr->location != location)	/* location failed */
 		{
@@ -2492,7 +2652,7 @@ label_edited_cb(GtkCellRendererText *cell, gchar *path_string,
 	if (gkrellm_locale_dup_string(&s->name, new_label, &s->name_locale))
 		{
 		gkrellm_sensors_rebuild(s->type == SENSOR_TEMPERATURE,
-				s->type == SENSOR_FAN, s->type == SENSOR_VOLTAGE);
+				s->type == SENSOR_FAN, s->type == SENSOR_VOLTAGE, s->type == SENSOR_POWER);
 		if (s->alert)
 			{
 			g_free(s->alert->name);
@@ -2521,13 +2681,13 @@ enable_cb(GtkCellRendererText *cell, gchar *path_string, gpointer data)
 				-1);
 	s->enabled = !enabled;
 	gtk_tree_store_set(GTK_TREE_STORE(model), &iter,
-				ENABLE_COLUMN, s->enabled, 
+				ENABLE_COLUMN, s->enabled,
 				-1);
     change_row_reference(model, path);
 	gtk_tree_path_free(path);
 
 	gkrellm_sensors_rebuild(s->type == SENSOR_TEMPERATURE,
-				s->type == SENSOR_FAN, s->type == SENSOR_VOLTAGE);
+			s->type == SENSOR_FAN, s->type == SENSOR_VOLTAGE, s->type == SENSOR_POWER);
 
 	set_sensor_widget_states(s);
 	}
@@ -2578,7 +2738,7 @@ cb_temperature_units(GtkWidget *button, gpointer data)
 	for (list = sensor_list; list; list = list->next)
 		fix_temp_alert((Sensor *) list->data);
 
-	gkrellm_sensors_rebuild(DO_TEMP, FALSE, FALSE);
+	gkrellm_sensors_rebuild(DO_TEMP, FALSE, FALSE, FALSE);
 	gkrellm_cpu_draw_sensors(NULL);
 	gkrellm_proc_draw_sensors(NULL);
 	}
@@ -2593,7 +2753,7 @@ cb_show_units(GtkWidget *button, gpointer data)
 		return;
 	show_units = show;
 
-	gkrellm_sensors_rebuild(DO_TEMP, FALSE, FALSE);
+	gkrellm_sensors_rebuild(DO_TEMP, FALSE, FALSE, FALSE);
 	gkrellm_cpu_draw_sensors(NULL);
 	gkrellm_proc_draw_sensors(NULL);
 	}
@@ -2606,7 +2766,7 @@ cb_voltages_display(GtkWidget *entry, gpointer data)
 	for (i = 0; i < N_DISPLAY_MODES; ++i)
 		if (gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(display_mode_button[i])))
 			display_mode = i;
-	gkrellm_sensors_rebuild(FALSE, FALSE, DO_VOLT);
+	gkrellm_sensors_rebuild(FALSE, FALSE, DO_VOLT, FALSE);
 	}
 
 static void
@@ -2665,7 +2825,7 @@ static gchar	*sensor_info_text0[] =
 	"\n",
 	};
 
-static gchar	*sensor_info_text1[] = 
+static gchar	*sensor_info_text1[] =
 	{
 N_("<h>Setup\n"),
 N_("Enter data scaling factors and offsets for the sensors if the default\n"
@@ -2707,7 +2867,6 @@ create_sensors_tab(GtkWidget *tab_vbox)
 	GList					*list;
 	SysdepOption			*so;
 	gchar					buf[32];
-	gint					i;
 
 	row_reference = NULL;
 	sensor_last_group = -1;
@@ -2777,7 +2936,7 @@ create_sensors_tab(GtkWidget *tab_vbox)
 
 	gtk_container_add(GTK_CONTAINER(scrolled), GTK_WIDGET(treeview));
 
-	selection = gtk_tree_view_get_selection(treeview);
+	GtkTreeSelection* selection = gtk_tree_view_get_selection(treeview);
 	gtk_tree_selection_set_mode(selection, GTK_SELECTION_SINGLE);
 	g_signal_connect(G_OBJECT(selection), "changed",
 				G_CALLBACK(cb_tree_selection_changed), NULL);
@@ -2903,10 +3062,12 @@ create_sensors_tab(GtkWidget *tab_vbox)
 				GTK_POLICY_AUTOMATIC, GTK_POLICY_AUTOMATIC);
 
 	if (!sensor_list)
-		for (i = 0; i < sizeof(sensor_info_text0) / sizeof(gchar *); ++i)
+		{
+		for (size_t i = 0; i < G_N_ELEMENTS(sensor_info_text0); ++i)
 			gkrellm_gtk_text_view_append(text, _(sensor_info_text0[i]));
+		}
 
-	for (i = 0; i < sizeof(sensor_info_text1) / sizeof(gchar *); ++i)
+	for (size_t i = 0; i < G_N_ELEMENTS(sensor_info_text1); ++i)
 		gkrellm_gtk_text_view_append(text, _(sensor_info_text1[i]));
 
 	/* Present as instant apply, but still get our apply function called.
@@ -2955,4 +3116,3 @@ gkrellm_init_sensors_config_monitor(void)
 	mon_config_sensors = &monitor_config_sensors;
 	return &monitor_config_sensors;
 	}
-
