@@ -1,7 +1,7 @@
 /* GKrellM
 |  Copyright (C) 1999-2021 Bill Wilson
 |
-|  Author:  Bill Wilson    billw@gkrellm.net
+|  Author:  Bill Wilson
 |  Latest versions might be found at:  https://gkrellm.srcbox.net
 |
 |  solaris.c code is Copyright (C) Daisuke Yabuki <dxy@acm.org>
@@ -40,7 +40,7 @@
 kstat_ctl_t *kc;
 kvm_t *kd = NULL;
 
-struct nlist nl[] = { 
+struct nlist nl[] = {
     { "mpid" },
     { 0 }
 };
@@ -51,8 +51,8 @@ extern void solaris_list_harddisks(void);
 void
 gkrellm_sys_main_init(void)
 {
-    /* 
-     * Most of stats (cpu, proc, disk, memory, net and uptime) are 
+    /*
+     * Most of stats (cpu, proc, disk, memory, net and uptime) are
      * unavailable if kstat_open() failed. So we just exit in that case.
      */
     if ((kc = kstat_open()) == NULL) {
@@ -61,18 +61,18 @@ gkrellm_sys_main_init(void)
     }
 
     /*
-     * kvm is utilized solely for getting a value for proc.n_forks 
+     * kvm is utilized solely for getting a value for proc.n_forks
      * from kernel variable called mpid. Even if kvm_open() fails,
      * we proceed without it.
      */
-    if ((kd = kvm_open(NULL, NULL, NULL, O_RDONLY, NULL)) != NULL) { 
+    if ((kd = kvm_open(NULL, NULL, NULL, O_RDONLY, NULL)) != NULL) {
         kvm_nlist(kd, nl);
     }
 
     /*
      * a function called by the following requires sys gid privilege.
      * the following function should be performed here just for that reason.
-     */ 
+     */
     solaris_list_harddisks();
 
     if (setgid(getgid()) != 0) {
@@ -106,7 +106,7 @@ gkrellm_sys_cpu_read_data(void)
     }
 
     for (ksp = kc->kc_chain; ksp; ksp = ksp->ks_next) {
-        if (strcmp(ksp->ks_module, "cpu_stat")) 
+        if (strcmp(ksp->ks_module, "cpu_stat"))
             continue;
         if (kstat_read(kc, ksp, &cs) == -1) {
             perror("kstat_read");
@@ -122,7 +122,7 @@ gkrellm_sys_cpu_read_data(void)
 }
 
 /*
- * note: on some SPARC systems, you can monitor temperature of CPUs 
+ * note: on some SPARC systems, you can monitor temperature of CPUs
  * with kstat (unix::temperature:[min/max/state/trend...])
  */
 
@@ -135,10 +135,10 @@ gkrellm_sys_cpu_init() {
     if(kstat_chain_update(kc) == -1) {
         perror("kstat_chain_update");
         return FALSE;
-    } 
+    }
 
     for (ksp = kc->kc_chain; ksp; ksp = ksp->ks_next) {
-        if (strcmp(ksp->ks_module, "cpu_stat")) 
+        if (strcmp(ksp->ks_module, "cpu_stat"))
             continue;
         if (kstat_read(kc, ksp, NULL) != -1) {
             gkrellm_cpu_add_instance(ksp->ks_instance);
@@ -167,7 +167,7 @@ gkrellm_sys_proc_read_data(void)
 {
 
     double avenrun[LOADAVG_NSTATS], fload = 0;
-    guint   n_processes = 0, n_forks = 0; 
+    guint   n_processes = 0, n_forks = 0;
     int last_pid;
     extern kstat_ctl_t *kc;
     kstat_t *ksp;
@@ -189,7 +189,7 @@ gkrellm_sys_proc_read_data(void)
     ksp = kstat_lookup(kc, "unix", -1, "system_misc");
     if (ksp && kstat_read(kc, ksp, NULL) >= 0) {
         knp = (kstat_named_t *)kstat_data_lookup(ksp, "nproc");
-        if (knp) { 
+        if (knp) {
             n_processes = knp->value.ui32;
         }
     }
@@ -218,7 +218,7 @@ gkrellm_sys_proc_read_users(void)
     while ((utmpp = getutent()) != NULL) {
         if (utmpp->ut_type == USER_PROCESS && utmpp->ut_name[0] != '\0')
             n_users++;
-    }    
+    }
     gkrellm_proc_assign_users(n_users);
 }
 
@@ -255,12 +255,6 @@ static gint check_media_type(kstat_t *);
 static gint isharddisk(kstat_t *);
 void solaris_list_harddisks(void);                   /* called from main.c */
 
-static gint lookup_name_to_major(name_to_major_t *, int);
-static gint get_major(gchar *);
-static gint get_devname(gint, gchar *);
-static gint get_minor(gint);
-static gint get_instance(gint); 
-
 typedef struct {
     char name[8];
 } probed_harddisk;
@@ -296,7 +290,7 @@ gkrellm_sys_disk_read_data(void)
         return;
     }
     for (ksp = kc->kc_chain; ksp; ksp = ksp->ks_next) {
-        if (ksp->ks_type != KSTAT_TYPE_IO || 
+        if (ksp->ks_type != KSTAT_TYPE_IO ||
             strcmp(ksp->ks_class, "disk")) {
             continue;
         }
@@ -329,115 +323,22 @@ gkrellm_sys_disk_init(void)
 }
 
 
-  /* Is this needed any longer? */
-static gint
-lookup_name_to_major(name_to_major_t *name_to_major, gint type) {
-    FILE *fp;
-    char line[80];
-    char *name, *maj;
-    gint name2major, major2name;
-    gint majnum;
-
-    name2major = major2name = 0;
-    switch (type) {
-        case NAME2MAJOR:
-            name2major = 1;
-            break;
-        case MAJOR2NAME:
-            major2name = 1;
-            break;
-        default:
-            break;
-    }
-
-    if ((fp = fopen("/etc/name_to_major", "r")) == NULL) {
-        perror("fopen");
-        return -1;
-    }
-
-    while (fgets(line, sizeof(line), fp) != NULL) {
-        name = strtok(line, " \t");
-        if (name == NULL)
-            continue;
-
-        maj = strtok(NULL, "\n");
-        if (maj == NULL)
-            continue;
-        majnum = (gint) atol(maj); 
-
-        if (name2major) {
-            if (strcmp(name_to_major->name, name) == 0) {
-                name_to_major->major = majnum;
-                fclose(fp);
-                return 0;
-            }
-        } else if (major2name) {
-            if (name_to_major->major == majnum) {
-                strcpy(name_to_major->name, name);
-                fclose(fp);
-                return 0; 
-            }
-        }
-    }
-    fclose(fp);
-    return -1;
-}
-
-#if 0
-  /* Is this needed any longer? */
-static gint
-get_major(gchar *devname) {
-    /* xlation from device name to major (e.g. sd -> 32) */
-    name_to_major_t name_to_major;
-
-    strcpy(name_to_major.name, devname);
-    if (lookup_name_to_major(&name_to_major, NAME2MAJOR) < 0)
-        return -1;
-    return name_to_major.major;
-}
-
-  /* Is this needed any longer? */
-static gint
-get_devname(gint major, gchar *devname) {
-    /* xlation from major to device name (e.g. 118 -> ssd) */
-    name_to_major_t name_to_major;
-
-    name_to_major.major = major;
-    if (lookup_name_to_major(&name_to_major, MAJOR2NAME) < 0)
-        return -1;
-    strcpy(devname, name_to_major.name);
-    return 0;
-}
-
-  /* Is this needed any longer? */
-static gint
-get_minor(gint instance) {
-    return instance << UNIT_SHIFT;
-}
-
-  /* Is this needed any longer? */
-static gint
-get_instance(gint minor) {
-    return minor >> UNIT_SHIFT;
-}
-#endif
-
-/* 
+/*
  * An sd instance could be a cdrom or a harddrive. You can't simply tell,
- * from contents of kstat, which type of device an sd device is 
+ * from contents of kstat, which type of device an sd device is
  * (well, maybe you could, but at least i can't.)
- * It, however, doesn't make much sense to count cdrom read/write as 
- * "Disk" activity. So I'd like to exclude removable media's from 
- * monitoring target. In order to do this, I try to open a physical 
+ * It, however, doesn't make much sense to count cdrom read/write as
+ * "Disk" activity. So I'd like to exclude removable media's from
+ * monitoring target. In order to do this, I try to open a physical
  * device of a corresponding sd instance. If it's succeeded, I assume
  * it's a hard drive. If I get ENXIO or EBUSY, I'll guess it's CDROM.
- * If you come up with a better (simpler or safer) way to tell it's 
- * a removable media or a hard drive, please drop me an e-mail at 
- * Daisuke Yabuki <dxy@acm.org>. 
- * I don't know any other driver which handle both hard drive and 
+ * If you come up with a better (simpler or safer) way to tell it's
+ * a removable media or a hard drive, please drop me an e-mail at
+ * Daisuke Yabuki <dxy@acm.org>.
+ * I don't know any other driver which handle both hard drive and
  * removable media, by the way. I hope it wouldn't do any harm on
- * other type of devices, i.e. ssd, or IDE drivers. 
- */ 
+ * other type of devices, i.e. ssd, or IDE drivers.
+ */
 static gint
 check_media_type(kstat_t *ksp) {
     gint fd;
@@ -506,13 +407,13 @@ check_media_type(kstat_t *ksp) {
     }
 
     return -1; /* shouldn't be reached */
-} 
+}
 
 static gint
 isharddisk(kstat_t *ksp) {
-    if (ksp->ks_type != KSTAT_TYPE_IO) 
+    if (ksp->ks_type != KSTAT_TYPE_IO)
         return 0;
-    if (strncmp(ksp->ks_class, "disk", 4)) 
+    if (strncmp(ksp->ks_class, "disk", 4))
         return 0; /* excluding nfs etc. */
     if (!strcmp(ksp->ks_module, "fd"))
         return 0; /* excluding fd */
@@ -521,7 +422,7 @@ isharddisk(kstat_t *ksp) {
     return 1;
 }
 
-/* 
+/*
  * creating a preliminary list of drives, which should be a complete
  * list of drives available on the system. the list is not supposed to
  * contain nfs, fd, cdrom, cdrw etc.
@@ -536,7 +437,7 @@ solaris_list_harddisks(void) {
         perror("kstat_chain_update");
         return;
     }
-    
+
     for (ksp = kc->kc_chain; ksp; ksp = ksp->ks_next) {
         if(isharddisk(ksp)) {
              drive = g_new0(probed_harddisk, 1);
@@ -566,9 +467,7 @@ gkrellm_sys_inet_read_tcp_data() {
     static int tcpfd = 0;
 
     mib2_tcpConnEntry_t *tp;
-#if defined(INET6)
     mib2_tcp6ConnEntry_t *tp6;
-#endif 
 
     char buf[512];
     int i, flags, getcode, num_ent;
@@ -615,7 +514,7 @@ gkrellm_sys_inet_read_tcp_data() {
                  toa->PRIM_type != T_OPTMGMT_ACK ||
                  toa->MGMT_flags != T_SUCCESS) {
              break;
-        } 
+        }
 
         if (ctlbuf.len >= sizeof (struct T_error_ack) &&
                  tea->PRIM_type == T_ERROR_ACK) {
@@ -628,7 +527,7 @@ gkrellm_sys_inet_read_tcp_data() {
                  toa->PRIM_type == T_OPTMGMT_ACK &&
                  toa->MGMT_flags == T_SUCCESS) {
              return;
-        } 
+        }
 
         /* prepare for receiving data */
         databuf.maxlen = mibhdr->len;
@@ -658,7 +557,6 @@ gkrellm_sys_inet_read_tcp_data() {
             }
         }
 
-#if defined(INET6)
         if (mibhdr->level == MIB2_TCP6 && mibhdr->name == MIB2_TCP6_CONN) {
             tp6 = (mib2_tcp6ConnEntry_t *)databuf.buf;
             num_ent = mibhdr->len / sizeof(mib2_tcp6ConnEntry_t);
@@ -667,15 +565,14 @@ gkrellm_sys_inet_read_tcp_data() {
                     continue;
                 tcp.local_port          = tp6->tcp6ConnLocalPort;
                 tcp.remote_port         = tp6->tcp6ConnRemPort;
-                memcpy(&tcp.remote_addr6, &tp6->tcp6ConnRemAddress, 
+                memcpy(&tcp.remote_addr6, &tp6->tcp6ConnRemAddress,
             sizeof(struct in6_addr));
                 tcp.family              = AF_INET6;
                 tcp_status = (tp6->tcp6ConnState == MIB2_TCP_established);
                 if (tcp_status == TCP_ALIVE)
                     gkrellm_inet_log_tcp_port_data(&tcp);
-            }  
+            }
         }
-#endif /* INET6 */
 
         free(databuf.buf);
     }
@@ -697,10 +594,10 @@ gkrellm_sys_inet_init(void)
 #include <sys/sockio.h>
 
 /*
- * FIXME: I haven't tested Net timer (and never will), but I believe it's 
- * not going to work. Name of the lock file is different from one on Linux. 
- * If you need this functionality, feel free to modify my code. 
- */ 
+ * FIXME: I haven't tested Net timer (and never will), but I believe it's
+ * not going to work. Name of the lock file is different from one on Linux.
+ * If you need this functionality, feel free to modify my code.
+ */
 
 void
 gkrellm_sys_net_read_data(void)
@@ -720,13 +617,13 @@ gkrellm_sys_net_read_data(void)
             kstat_read(kc, ksp, NULL);
 
             knp = kstat_data_lookup(ksp, "rbytes");
-            if (knp == NULL) 
+            if (knp == NULL)
                 continue;
 
             rx = knp->value.ui32;
 
             knp = kstat_data_lookup(ksp, "obytes");
-            if (knp == NULL) 
+            if (knp == NULL)
                 continue;
 
             tx = knp->value.ui32;
@@ -737,77 +634,6 @@ gkrellm_sys_net_read_data(void)
 
 }
 
-#if 0
-/* New way is for above gkrellm_sys_net_read_data() to just assign data
-|  for all net interfaces.
-*/
-void
-gkrellm_sys_net_sync(void)
-    {
-    GList *list;    
-    int numifs, numifreqs;
-    int i, sockfd;
-    size_t bufsize;
-    gchar   *buf;
-    struct ifreq ifr, *ifrp;
-    struct ifconf ifc;
-
-    if ((sockfd = socket(AF_INET, SOCK_DGRAM, 0)) < 0) 
-    return;
-    
-    if (ioctl(sockfd, SIOCGIFNUM, (char *)&numifs) < 0) {
-        perror("SIOCGIFNUM");
-        close(sockfd);
-        return;
-    }
-
-    bufsize = ((size_t)numifs) * sizeof(struct ifreq);
-    buf = (char *)malloc(bufsize);
-    if (!buf) {
-        perror("malloc");
-        close(sockfd);
-        return;
-    }
-
-    ifc.ifc_len = bufsize; 
-    ifc.ifc_buf = buf;
-
-    if (ioctl(sockfd, SIOCGIFCONF, (char *)&ifc) < 0) {
-        perror("SIOCGIFCONF");
-        free(buf);
-        close(sockfd);
-        return;
-    }
-
-#ifdef DEBUG
-    g_message("interfaces probed: ");
-    for (i=0; i < numifs; i++) {
-        g_message("%s ", ifc.ifc_req[i].ifr_name);
-    }
-    g_message("\n");
-#endif
-    
-    ifrp = ifc.ifc_req;
-    numifreqs = ifc.ifc_len / sizeof(struct ifreq);
-
-    for (i = 0; i < numifreqs; i++, ifrp++)
-        {
-        memset((char *)&ifr, 0, sizeof(ifr));
-        strncpy(ifr.ifr_name, ifrp->ifr_name, sizeof(ifr.ifr_name));
-        if (!strncmp(ifr.ifr_name, "lo", 2)) 
-            continue;
-        if (ioctl(sockfd, SIOCGIFFLAGS, &ifr) < 0)
-            {
-            perror("SIOCGIFFLAGS");
-            continue;
-            }
-        if (ifr.ifr_flags & IFF_UP)
-            gkrellm_net_interface_is_up(ifr.ifr_name);
-        }
-    free(buf);
-    close(sockfd);
-    }
-#endif
 
 gboolean
 gkrellm_sys_net_isdn_online(void)
@@ -849,7 +675,7 @@ gkrellm_sys_mem_read_data() {
     static gulong pageshift = 0, physpages = 0;
     extern kstat_ctl_t *kc;
     kstat_t *ksp;
-    kstat_named_t *knp;  
+    kstat_named_t *knp;
 
     struct anoninfo ai;
 
@@ -887,9 +713,9 @@ gkrellm_sys_mem_read_data() {
     swap_used  <<= pageshift;
 
     /* NEED TO BE COMPLETED
-     * mem.x_used, mem.shared, mem.buffers, mem.cached 
-     * swap_chart.page_in, swap_chart.page_out (for swap pages in/out chart) 
-     */ 
+     * mem.x_used, mem.shared, mem.buffers, mem.cached
+     * swap_chart.page_in, swap_chart.page_out (for swap pages in/out chart)
+     */
 
 }
 
@@ -942,7 +768,7 @@ gkrellm_sys_fs_get_fstab_list(){
             continue;
         gkrellm_fs_add_to_fstab_list(
                 vfsbuf.vfs_mountp  ? vfsbuf.vfs_mountp  : "",
-                vfsbuf.vfs_special ? vfsbuf.vfs_special : "",               
+                vfsbuf.vfs_special ? vfsbuf.vfs_special : "",
                 vfsbuf.vfs_fstype  ? vfsbuf.vfs_fstype  : "",
                 vfsbuf.vfs_mntopts ? vfsbuf.vfs_mntopts : "");
     }
@@ -950,7 +776,7 @@ gkrellm_sys_fs_get_fstab_list(){
     fclose(fp);
 }
 
-void 
+void
 gkrellm_sys_fs_get_mounts_list(void){
     FILE *fp;
     struct mnttab mntbuf;
@@ -959,7 +785,7 @@ gkrellm_sys_fs_get_mounts_list(void){
         return;
 
     while (getmntent(fp, &mntbuf) == 0) {
-        if (strcmp(mntbuf.mnt_fstype, "ufs") && 
+        if (strcmp(mntbuf.mnt_fstype, "ufs") &&
                                   strcmp(mntbuf.mnt_fstype, "nfs"))
             continue;
         gkrellm_fs_add_to_mounts_list(
@@ -980,7 +806,7 @@ gkrellm_sys_fs_get_fsusage(gpointer fs, gchar *dir){
                     (glong) st.f_bfree, (glong) st.f_bsize);
     } else {
         gkrellm_fs_assign_fsusage_data(fs, 0, 0, 0, 0);
-    } 
+    }
 }
 
 static void
@@ -1009,13 +835,13 @@ void
 gkrellm_sys_battery_read_data(void)
 {
 }
- 
+
 gboolean
 gkrellm_sys_battery_init(void)
 {
       return FALSE;
 }
- 
+
 /* ===================================================================== */
 /* Uptime monitor interface */
 
@@ -1045,20 +871,20 @@ gkrellm_sys_uptime_init(void) {
     ksp = kstat_lookup(kc, "unix", -1, "system_misc");
     if (ksp && kstat_read(kc, ksp, NULL) >= 0) {
         knp = (kstat_named_t *)kstat_data_lookup(ksp, "boot_time");
-        if (knp) { 
+        if (knp) {
             boot = knp->value.ui32;
         }
     }
     if (time(&now) < 0)
         return FALSE;
-    if (now <= boot) 
+    if (now <= boot)
         return FALSE;
 
     base_uptime = now - boot;
     base_uptime += 30;
     gkrellm_uptime_set_base_uptime(base_uptime);
 
-    return (base_uptime == (time_t) 0) ? FALSE : TRUE; 
+    return (base_uptime == (time_t) 0) ? FALSE : TRUE;
 }
 
 
@@ -1066,6 +892,13 @@ gkrellm_sys_uptime_init(void) {
 /* Sensor monitor interface */
 /* (nonfunctional) */
 
+gboolean
+gkrellm_sys_sensors_get_power(gchar *path, gint id,
+		gint iodev, gint interface, gfloat *power)
+{
+	return FALSE;
+}
+
 gboolean
 gkrellm_sys_sensors_init(void)
 {
